@@ -9,7 +9,7 @@
 	*  Free Software Foundation; either version 2 of the License, or (at your  *
 	*  option) any later version.                                              *
 	\**************************************************************************/
-	/* $Id: class.uiaccounts.inc.php,v 1.70 2007/02/03 22:22:15 sigurdne Exp $ */
+	/* $Id: class.uiaccounts.inc.php,v 1.71 2007/05/08 10:55:46 sigurdne Exp $ */
 
 	class uiaccounts
 	{
@@ -138,7 +138,7 @@
 
 			$nm = array
 			(
-				'start_record'	=> $start,
+				'start'	=> $start,
  				'num_records'	=> count($account_info),
  				'all_records'	=> $total,
 				'link_data'		=> $link_data
@@ -176,8 +176,9 @@
 
 			//this is a work around hack for the ugly nextmatch code
 			$query = $GLOBALS['query'] = isset($_POST['query']) ? $_POST['query'] : '';
-			$start = isset($_POST['start']) ? (int) $_POST['start'] : '';
 
+			$start = (int) isset($_REQUEST['start']) ? $_REQUEST['start']: 0;
+			
 			if(isset($_GET['order']))
 			{
 				$order = $_GET['order'];
@@ -289,7 +290,7 @@
 
 			$nm = array
 			(
-				'start_record'	=> $start,
+				'start'			=> $start,
  				'num_records'	=> count($account_info),
  				'all_records'	=> $total,
 				'link_data'		=> $link_data
