@@ -8,7 +8,7 @@
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package phpgroupware
 	* @subpackage help
-	* @version $Id: help.php,v 1.1 2007/02/06 13:43:24 sigurdne Exp $
+	* @version $Id: help.php,v 1.2 2007/02/20 14:09:30 sigurdne Exp $
 	*/
 
 	/**
@@ -37,6 +37,8 @@
 	*/
 	include_once('header.inc.php');
 
+	$GLOBALS['phpgw_info']['flags']['xslt_app'] = True;
+	
 	$GLOBALS['phpgw']->help = CreateObject('phpgwapi.help_helper');
 
 	if ($app == 'help')
@@ -48,5 +50,11 @@
 		$GLOBALS['phpgw']->hooks->single('help',$app);
 	}
 
-	$GLOBALS['phpgw']->xslttpl->set_var('phpgw',$GLOBALS['phpgw']->help->output);
+	$appname		= lang('Help');
+	$function_msg	= lang('app');
+
+	$GLOBALS['phpgw_info']['flags']['app_header'] = $appname . ' - ' . $appname;
+
+	$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('help' => $GLOBALS['phpgw']->help->output));
+
 ?>
