@@ -6,7 +6,7 @@
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage accounts
-	* @version $Id: class.acl.inc.php,v 1.4 2007/02/24 20:32:46 sigurdne Exp $
+	* @version $Id: class.acl.inc.php,v 1.8 2007/03/28 09:52:36 sigurdne Exp $
 	*/
 
 	/**
@@ -89,14 +89,22 @@
 			{
 				$GLOBALS['phpgw']->shm = createObject('phpgwapi.shm');
 			}
-
-			if ( isset($GLOBALS['phpgw_info']['server']['shm_lang']) && $GLOBALS['phpgw_info']['server']['shm_lang']
-				&& function_exists('sem_get'))
-			{
-				$this->load_from_shm = true;
-			}
 		}
 
+		/**
+		* Checks whether the system is set to utilise shared memory
+		* @return bool ACL data loaded from shared memory
+		*/
+		function load_from_shm()
+		{
+			if ((isset($GLOBALS['phpgw_info']['server']['shm_lang']) 
+				&& $GLOBALS['phpgw_info']['server']['shm_lang'])
+				&& function_exists('sem_get'))
+			{
+				return true;
+			}
+		}
+		
 		/**
 		* Get list of xmlrpc or soap functions
 		*
@@ -163,14 +171,17 @@
 			{
 				$this->acl();
 			}
-
-			if ( $GLOBALS['phpgw_info']['server']['account_repository'] == 'ldap' )
+			if ( !$this->load_from_shm()
+				|| !($this->data[$this->account_id] = $GLOBALS['phpgw']->shm->get_value($GLOBALS['phpgw_info']['user']['domain'] . 'acl_data_' . $account_type . '_' . $this->account_id)))
 			{
-				return $this->_read_repository_ldap($account_type);
-			}
-			else
-			{
-				return $this->_read_repository_sql($account_type);
+				if ( $GLOBALS['phpgw_info']['server']['account_repository'] == 'ldap' )
+				{
+					return $this->_read_repository_ldap($account_type);
+				}
+				else
+				{
+					return $this->_read_repository_sql($account_type);
+				}
 			}
 		}
 
@@ -450,12 +461,7 @@
 
 			$this->db->transaction_commit();
 
-			if($this->load_from_shm)
-			{
-				$GLOBALS['phpgw']->shm->delete_key($GLOBALS['phpgw_info']['user']['domain'] . 'acl_data_groups_' . $this->account_id);
-				$GLOBALS['phpgw']->shm->delete_key($GLOBALS['phpgw_info']['user']['domain'] . 'acl_data_accounts_' . $this->account_id);
-				$GLOBALS['phpgw']->shm->delete_key($GLOBALS['phpgw_info']['user']['domain'] . 'acl_data_both_' . $this->account_id);
-			}
+			$this->clean_shm($this->account_id);
 
 //			return $unique_data;
 		}
@@ -487,12 +493,12 @@
 
 			if (!isset($this->data[$this->account_id]) || count($this->data[$this->account_id]) == 0)
 			{
-				if($this->load_from_shm)
+				if($this->load_from_shm())
 				{
 					$this->data[$this->account_id] = $GLOBALS['phpgw']->shm->get_value($GLOBALS['phpgw_info']['user']['domain'] . 'acl_data_' . $account_type . '_' . $this->account_id);
 					if((is_array($this->data[$this->account_id]) && count($this->data[$this->account_id])==0) || $this->data[$this->account_id] == 'empty')
 					{
-						$this->data[$this->account_id] = array();
+							$this->data[$this->account_id] = array();
 					}
 					else
 					{
@@ -761,6 +767,9 @@
 				$sql .= " values ('" . $app . "','" . $acl_location . "','" . $account_id . "','" . intval($rights) . "', NULL ,'0')";
 				$this->db->query($sql ,__LINE__,__FILE__);
 			}
+
+			$this->clean_shm($account_id);
+
 			return true;
 		}
 
@@ -795,6 +804,9 @@
 
 			$sql = "DELETE FROM phpgw_acl WHERE acl_appname LIKE '{$app}' AND acl_location LIKE '{$location}' $account_sel";
 			$this->db->query($sql ,__LINE__,__FILE__);
+
+			$this->clean_shm($account_id);
+			
 			return $this->db->num_rows();
 		}
 			
@@ -1253,13 +1265,13 @@
 			{
 				$this->data[$this->account_id][] = array
 				(
-					'appname'	=> $this->db->f('acl_appname'),
-					'location'	=> $this->db->f('acl_location'), 
-					'account'	=> $this->db->f('acl_account'),
-					'rights'	=> $this->db->f('acl_rights'),
-					'grantor'	=> $this->db->f('acl_grantor'),
-					'type'		=> $this->db->f('acl_type'),
-					'account_type' => $this->db->f('account_type')
+					'appname'	=> $this->db->Record['acl_appname'],// $this->db->f('acl_appname'),
+					'location'	=> $this->db->Record['acl_location'],// $this->db->f('acl_location'), 
+					'account'	=> $this->db->Record['acl_account'],// $this->db->f('acl_account'),
+					'rights'	=> $this->db->Record['acl_rights'],// $this->db->f('acl_rights'),
+					'grantor'	=> $this->db->Record['acl_grantor'],// $this->db->f('acl_grantor'),
+					'type'		=> $this->db->Record['acl_type'],// $this->db->f('acl_type'),
+					'account_type' => $this->db->Record['account_type'] // $this->db->f('account_type')
 				);
 			}
 			return $this->data;
@@ -1301,4 +1313,32 @@
 
 			return $acl_accounts;
 		}
+
+		/**
+		* Delete ACL information from shared memory
+		*
+		* @param integer $account_id
+		*/
+		function clean_shm($account_id)
+		{
+			if($this->load_from_shm())
+			{
+				$GLOBALS['phpgw']->shm->delete_key($GLOBALS['phpgw_info']['user']['domain'] . 'acl_data_groups_' . $account_id);
+				$GLOBALS['phpgw']->shm->delete_key($GLOBALS['phpgw_info']['user']['domain'] . 'acl_data_accounts_' . $account_id);
+				$GLOBALS['phpgw']->shm->delete_key($GLOBALS['phpgw_info']['user']['domain'] . 'acl_data_both_' . $account_id);
+
+				$members = $this->get_ids_for_location($account_id, 1, 'phpgw_group');
+
+				if (is_array($members) && count($members) > 0)
+				{
+					foreach ( $members as $account_id )
+					{
+						$GLOBALS['phpgw']->shm->delete_key($GLOBALS['phpgw_info']['user']['domain'] . 'acl_data_groups_' . $account_id);
+						$GLOBALS['phpgw']->shm->delete_key($GLOBALS['phpgw_info']['user']['domain'] . 'acl_data_accounts_' . $ccount_id);
+						$GLOBALS['phpgw']->shm->delete_key($GLOBALS['phpgw_info']['user']['domain'] . 'acl_data_both_' . $account_id);
+					}
+				}
+			}
+
+		}
 	}
