@@ -8,7 +8,7 @@
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage utilities
-	* @version $Id: class.common.inc.php,v 1.3 2007/02/08 09:53:18 sigurdne Exp $
+	* @version $Id: class.common.inc.php,v 1.7 2007/04/08 17:42:28 sigurdne Exp $
 	*/
 
 	/**
@@ -1098,8 +1098,12 @@
 			}
 
 			// We handle this here becuase its special
-			$GLOBALS['phpgw_info']['navbar']['about']['title'] = lang('About %1', $app_title);
+			if(isset($GLOBALS['phpgw_info']['navbar']['manual']))
+			{
+				$GLOBALS['phpgw_info']['navbar']['manual']['url']   = "javascript:openwindow('" . $GLOBALS['phpgw']->link('/index.php', array('menuaction'=> 'manual.uimanual.help', 'app' => isset($GLOBALS['phpgw_info']['apps']['manual']['app']) && $GLOBALS['phpgw_info']['apps']['manual']['app'] ? $GLOBALS['phpgw_info']['apps']['manual']['app'] : $app, 'section' => isset($GLOBALS['phpgw_info']['apps']['manual']['section'])?$GLOBALS['phpgw_info']['apps']['manual']['section']:'')) . "','700','600')";
+			}
 
+			$GLOBALS['phpgw_info']['navbar']['about']['title'] = lang('About %1', $app_title);
 			$GLOBALS['phpgw_info']['navbar']['about']['url']   = $GLOBALS['phpgw']->link('/about.php', array('app' => $app) );
 			$GLOBALS['phpgw_info']['navbar']['about']['icon']  = $this->image('phpgwapi',Array('about','nonav'));
 			$GLOBALS['phpgw_info']['navbar']['about']['icon_hover']  = $this->image_on('phpgwapi',Array('about','nonav'),'-over');
