@@ -8,7 +8,7 @@
 	* @license http://www.gnu.org/licenses/lpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage gui
-	* @version $Id: class.xslttemplates.inc.php,v 1.3 2007/02/17 22:08:32 sigurdne Exp $
+	* @version $Id: class.xslttemplates.inc.php,v 1.4 2007/03/16 21:40:54 sigurdne Exp $
 	*/
 
 	if( (floor(phpversion()) == 4 && !extension_loaded('xslt') )
@@ -224,7 +224,7 @@
 		{
 			if( is_array($this->xslfiles) && count($this->xslfiles) > 0)
 			{
-				$this->xsldata = '<?xml version="1.0" encoding="UTF-8"?>'."\n";
+				$this->xsldata = '<?xml version="1.0" encoding="' . $GLOBALS['phpgw_info']['server']['charset'] . '"?>'."\n";
 				$this->xsldata .= '<!DOCTYPE xsl:stylesheet ['."\n";
 				$this->xsldata .= '<!ENTITY nl "&#10;">'."\n";
 				$this->xsldata .= '<!ENTITY nbsp "&#160;">'."\n";
@@ -233,13 +233,13 @@
 
 				if(!$wml_out)
 				{
- 					$this->xsldata .= '<xsl:output method="html" version="1.0" encoding="UTF-8" indent="yes" omit-xml-declaration="yes" standalone="yes" media-type="application/xml+xhtml"/>'."\n";
+ 					$this->xsldata .= '<xsl:output method="html" version="1.0" encoding="' . $GLOBALS['phpgw_info']['server']['charset'] . '" indent="yes" omit-xml-declaration="yes" standalone="yes" media-type="application/xml+xhtml"/>'."\n";
 	 				//FIXME Remove the line above and uncomment the one below once the main templates are converted or else it fscks validation
- 					//$this->xsldata .= '<xsl:output method="html" version="1.0" encoding="UTF-8" indent="yes" omit-xml-declaration="yes" doctype-public="-//W3C/DTD XHTML 1.0 Transitional//EN" doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd" standalone="yes" media-type="application/xml+xhtml"/>'."\n";
+ 					//$this->xsldata .= '<xsl:output method="html" version="1.0" encoding="' . $GLOBALS['phpgw_info']['server']['charset'] . '" indent="yes" omit-xml-declaration="yes" doctype-public="-//W3C/DTD XHTML 1.0 Transitional//EN" doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd" standalone="yes" media-type="application/xml+xhtml"/>'."\n";
 				}
 				else
 				{
-					$this->xsldata .= '<xsl:output method = "xml" encoding="UTF-8"  doctype-public="-//WAPFORUM//DTD WML 1.3//EN" doctype-system="http://www.wapforum.org/DTD/wml13.dtd" />'."\n";				
+					$this->xsldata .= '<xsl:output method = "xml" encoding="' . $GLOBALS['phpgw_info']['server']['charset'] . '"  doctype-public="-//WAPFORUM//DTD WML 1.3//EN" doctype-system="http://www.wapforum.org/DTD/wml13.dtd" />'."\n";				
 
 				}
 				$this->xsldata .= '<xsl:template match="/">'."\n";
