@@ -10,7 +10,7 @@
 	* @license http://www.fsf.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage accounts
-	* @version $Id: class.sessions.inc.php,v 1.1 2007/02/06 12:42:23 sigurdne Exp $
+	* @version $Id: class.sessions.inc.php,v 1.2 2007/03/16 08:51:43 sigurdne Exp $
 	* @link http://www.sanisoft.com/phplib/manual/session.php
 	*/
 
@@ -1112,8 +1112,8 @@
 		*/
 		function link($url, $extravars = array(), $redirect=false)
 		{
-	//		$term = '&amp;'; //W3C Compliant in markup
-			$term = '&'; // to make enable apps from .16
+			$term = '&amp;'; //W3C Compliant in markup
+		//	$term = '&'; // to make enable apps from .16
 			if ( $redirect )
 			{
 				$term = '&'; // RFC Compliant for Header('Location: ...
