@@ -8,7 +8,7 @@
 	* @license http://www.fsf.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage database
-	* @version $Id: class.sql_pgsql.inc.php,v 1.1 2007/02/06 12:42:23 sigurdne Exp $
+	* @version $Id: class.sql_pgsql.inc.php,v 1.2 2007/03/01 07:52:44 sigurdne Exp $
 	* @internal Development of this application was funded by http://www.sogrp.com
 	* @link http://www.sogrp.com/
 	*/
@@ -41,5 +41,13 @@
 		{
 			return sql_criteria::upper($field).' ILIKE '."'%$value%'";
 		}
+		function begin_with($field, $value)
+		{
+			return sql_criteria::upper($field).' ILIKE '."'$value%'";
+		}
+		function end_with($field, $value)
+		{
+			return sql_criteria::upper($field).' ILIKE '."'%$value'";
+		}
 	}
 ?>
