@@ -1,11 +1,11 @@
 <?php
 	/**
 	* Setup
-	* @copyright Copyright (C) 2003-2005 Free Software Foundation, Inc. http://www.fsf.org/
+	* @copyright Copyright (C) 2003,2004,2005,2006,2007 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage setup
-	* @version $Id: tables_update.inc.php,v 1.8 2007/02/27 12:30:33 sigurdne Exp $
+	* @version $Id: tables_update.inc.php,v 1.11 2007/05/21 11:58:31 sigurdne Exp $
 	* @internal $Source: /sources/fmsystem/phpgwapi/setup/tables_update.inc.php,v $
 	*/
 
@@ -1422,6 +1422,42 @@
 	{
 		$GLOBALS['phpgw_setup']->oProc->m_odb->transaction_begin();
 
+//	----sync with the official 0_9_16_011
+		$metadata = $GLOBALS['phpgw_setup']->db->metadata('phpgw_acl');
+		if(!isset($metadata['acl_grantor']) || !$metadata['acl_grantor'])
+		{
+			$GLOBALS['phpgw_setup']->oProc->AddColumn('phpgw_acl','acl_grantor',array(
+				'type' => 'int',
+				'precision' => '4',
+				'nullable' => True
+			));
+
+			$GLOBALS['phpgw_setup']->oProc->AddColumn('phpgw_acl','acl_type',array(
+				'type' => 'int',
+				'precision' => '2',
+				'nullable' => True
+			));
+
+			$GLOBALS['phpgw_setup']->oProc->CreateTable(
+				'phpgw_acl_location', array(
+					'fd' => array(
+						'appname' => array('type' => 'varchar','precision' => '25','nullable' => False),
+						'id' => array('type' => 'varchar','precision' => '50','nullable' => False),
+						'descr' => array('type' => 'varchar','precision' => '50','nullable' => False),
+						'allow_grant' => array('type' => 'int','precision' => '4','nullable' => True)
+					),
+					'pk' => array('appname','id'),
+					'fk' => array(),
+					'ix' => array(),
+					'uc' => array()
+				)
+			);
+
+			$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_acl_location (appname,id, descr) VALUES ('hrm', '.', 'Top')");
+			$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_acl_location (appname,id, descr, allow_grant) VALUES ('hrm', '.user', 'User',1)");
+			$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_acl_location (appname,id, descr) VALUES ('hrm', '.job', 'Job description')");
+		}
+
 		$GLOBALS['phpgw_setup']->oProc->CreateTable(
 			'phpgw_cust_attribute', array(
 				'fd' => array(
@@ -1601,4 +1637,14 @@
 		}
 		return $GLOBALS['setup_info']['phpgwapi']['currentver'];
 	}
+	/**
+	* Update phpgwapi version from 0.9.17.001 to 0.9.17.002
+	*/
+
+	$test[] = '0.9.17.001';
+	function phpgwapi_upgrade0_9_17_001()
+	{
+		$GLOBALS['setup_info']['phpgwapi']['currentver'] = '0.9.17.002';		
+		return $GLOBALS['setup_info']['phpgwapi']['currentver'];
+	}
 ?>
