@@ -5,7 +5,7 @@
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage gui
-	* @version $Id: navbar.inc.php,v 1.6 2007/02/20 11:15:20 sigurdne Exp $
+	* @version $Id: navbar.inc.php,v 1.8 2007/03/21 15:37:04 sigurdne Exp $
 	*/
 
 
@@ -74,10 +74,9 @@
 					$title .= '<br>' . $app_data['title'];
 				}
 				$applications .= '<br><a href="' . $app_data['url'] . '"';
-				if (isset($GLOBALS['phpgw_info']['flags']['navbar_target']) &&
-				    $GLOBALS['phpgw_info']['flags']['navbar_target'])
+				if (isset($app_data['target']) &&  $app_data['target'])
 				{
-					$applications .= ' target="' . $GLOBALS['phpgw_info']['flags']['navbar_target'] . '"';
+					$applications .= ' target="' . $app_data['target'] . '"';
 				}
 				$applications .= '>' . $title . '</a>';
 				unset($title);
@@ -118,7 +117,7 @@
 			$var['preferences_img'] = $GLOBALS['phpgw']->common->image('phpgwapi','preferences-grey');
 		}
 		$var['logout_img'] = $GLOBALS['phpgw']->common->image('phpgwapi','logout-grey');
-
+/*
 		$var['powered_by'] = lang('Powered by phpGroupWare version %1',$GLOBALS['phpgw_info']['server']['versions']['phpgwapi']);
 
 		if (isset($GLOBALS['phpgw_info']['navbar']['admin']) && isset($GLOBALS['phpgw_info']['user']['preferences']['common']['show_currentusers']))
@@ -133,7 +132,7 @@
 			. $GLOBALS['phpgw']->common->show_date($now,$GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat']);
 //			. lang($GLOBALS['phpgw']->common->show_date($now,'F')) . ' '
 //			. $GLOBALS['phpgw']->common->show_date($now,'d, Y');
-
+*/
 		// Maybe we should create a common function in the phpgw_accounts_shared.inc.php file
 		// to get rid of duplicate code.
 		if (!isset($GLOBALS['phpgw_info']['user']['lastpasswd_change']) || $GLOBALS['phpgw_info']['user']['lastpasswd_change'] == 0)
@@ -213,7 +212,9 @@
 			'table_bg_color'	=> (isset($GLOBALS['phpgw_info']['theme']['navbar_bg'])?$GLOBALS['phpgw_info']['theme']['navbar_bg']:''),
 			'version'		=> $GLOBALS['phpgw_info']['server']['versions']['phpgwapi']
 		);
-		if (isset($GLOBALS['phpgw_info']['navbar']['admin']) && isset($GLOBALS['phpgw_info']['user']['preferences']['common']['show_currentusers']))
+		if (isset($GLOBALS['phpgw_info']['navbar']['admin']) 
+			&& isset($GLOBALS['phpgw_info']['user']['preferences']['common']['show_currentusers'])
+			&& $GLOBALS['phpgw_info']['user']['preferences']['common']['show_currentusers'] > 0)
 		{
 			$var['current_users'] = '<a style="font-family: Geneva,Arial,Helvetica,sans-serif; font-size: 12pt;" href="'
 				. $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'admin.uicurrentsessions.list_sessions')) . '">&nbsp;'
