@@ -5,7 +5,7 @@
 	* @copyright Copyright (C) 2000-2006 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package preferences
-	* @version $Id: preferences.php,v 1.46 2007/02/26 19:26:58 sigurdne Exp $
+	* @version $Id: preferences.php,v 1.47 2007/03/25 19:38:39 sigurdne Exp $
 	*/
 
 	$GLOBALS['phpgw_info']['flags'] = array
@@ -381,7 +381,7 @@
 			}
 			$def_text = $def_text != '' ? '<br><i><font size="-1"><b>'.lang('default').'</b>:<br>'.nl2br($def_text).'</font></i>' : '';
 		}
-		$t->set_var('row_value',"<textarea rows=\"$rows\" cols=\"$cols\" name=\"${GLOBALS['type']}[$name]\">".htmlentities($default,ENT_QUOTES,'UTF-8')."</textarea>$def_text");
+		$t->set_var('row_value',"<textarea rows=\"$rows\" cols=\"$cols\" name=\"${GLOBALS['type']}[$name]\">".htmlentities($default,ENT_QUOTES,isset($GLOBALS['phpgw_info']['server']['charset']) && $GLOBALS['phpgw_info']['server']['charset'] ? $GLOBALS['phpgw_info']['server']['charset'] : 'UTF-8')."</textarea>$def_text");
 		$t->set_var('row_name',lang($label));
 		$GLOBALS['phpgw']->nextmatchs->template_alternate_row_class($t);
 
