@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage admin
- 	* @version $Id: class.boadmin.inc.php,v 1.19 2007/01/26 14:53:46 sigurdne Exp $
+ 	* @version $Id: class.boadmin.inc.php,v 1.20 2007/03/21 15:36:02 sigurdne Exp $
 	*/
 
 	/**
@@ -49,7 +49,7 @@
 			$this->so 			= CreateObject($this->currentapp.'.soadmin');
 			$this->acl 			= CreateObject('phpgwapi.acl');
 			$this->bocommon 	= CreateObject($this->currentapp.'.bocommon');
-			$this->right		= array(1,2,4,8,16,32,64,128);
+			$this->right		= array(1,2,4,8,16);
 
 			if ($session)
 			{
@@ -331,6 +331,11 @@
 				}
 			}
 
+			if($this->location == '.invoice')
+			{
+				$this->right		= array(1,2,4,8,16,32,64,128);
+			}
+
 			$right=$this->right;
 
 			$offset = $GLOBALS['phpgw_info']['user']['preferences']['common']['maxmatchs'];
@@ -362,6 +367,7 @@
 					$this->acl->read_repository();
 
 					$count_right=count($right);
+					
 					for ( $i = 0; $i < $count_right; ++$i )
 					{
 						if($this->acl->check_brutto($this->location, $right[$i],$this->acl_app,$grantor,0,$check_account_type))
