@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage core
- 	* @version $Id: class.bocommon.inc.php,v 1.62 2007/02/19 21:02:41 sigurdne Exp $
+ 	* @version $Id: class.bocommon.inc.php,v 1.66 2007/03/22 10:35:27 sigurdne Exp $
 	*/
 
 	/**
@@ -182,8 +182,12 @@
 		}
 
 
-		function date_array($datestr)
+		function date_array($datestr = '')
 		{
+			if(!$datestr)
+			{
+				return false;
+			}
 			$dateformat = $GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'];
 
 			$fields = split('[./-]',$datestr);
@@ -402,15 +406,38 @@
 		}
 
 
-		function get_user_list_right($right='',$selected='',$acl_location='')
+		function get_user_list_right($right='',$selected='',$acl_location='',$extra='',$default='')
 		{
-			if(!$employees = $this->socommon->fm_cache('acl_userlist_'. $right . '_' . $acl_location))
+			if(!$selected && $default)
 			{
-				$employees=$this->socommon->get_user_list_right($right,$acl_location);
-				$this->socommon->fm_cache('acl_userlist_'. $right . '_' . $acl_location,$employees);
+				$selected = $default;
 			}
 
-			while (is_array($employees) && list(,$user) = each($employees))
+			if (is_array($extra))
+			{
+				foreach($extra as $extra_user)
+				{
+					$users_extra[]=array
+					(
+						'account_lid' => $extra_user,
+						'account_firstname' => lang($extra_user)
+					);
+				}
+			}
+
+			if(!$users = $this->socommon->fm_cache('acl_userlist_'. $right . '_' . $acl_location))
+			{
+				$users=$this->socommon->get_user_list_right($right,$acl_location);
+				$this->socommon->fm_cache('acl_userlist_'. $right . '_' . $acl_location,$users);
+			}
+
+			if (is_array($users_extra) && is_array($users))
+			{
+				$users = $users_extra + $users;
+			}
+
+
+			while (is_array($users) && list(,$user) = each($users))
 			{
 				if ($user['account_lid']==$selected)
 				{
@@ -1454,22 +1481,47 @@
 			return $values;
 		}
 		
+		/**
+		* Converts utf-8 to ascii
+		*
+		* @param string $text string
+		* @return string ascii encoded 
+		*/
+		function utf2ascii($text = '')
+		{	
+			if($GLOBALS['phpgw_info']['server']['charset']=='utf-8')
+			{
+				if ($text == utf8_decode($text))
+				{
+					return $text;
+				}
+				else
+				{
+					return utf8_decode($text);
+				}
+			}
+			else
+			{
+				return $text;
+			}
+		}
+
 		/**
 		* Converts ascii to utf-8
 		*
 		* @param string $text string
 		* @return string utf-8 encoded 
 		*/
-		function utf2ascii($text = '')
+		function ascii2utf($text = '')
 		{	
-			if ($text == utf8_decode($text))
+			if ($GLOBALS['phpgw_info']['server']['charset']=='utf-8')
 			{
-				return $text;
+				return utf8_encode($text);
 			}
 			else
 			{
-				return utf8_decode($text);
+				return $text;
 			}
-		}
+		}		
 	}
 ?>
