@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage location
- 	* @version $Id: class.bolocation.inc.php,v 1.31 2007/02/19 21:02:41 sigurdne Exp $
+ 	* @version $Id: class.bolocation.inc.php,v 1.32 2007/03/16 14:31:10 sigurdne Exp $
 	*/
 
 	/**
@@ -568,7 +568,7 @@
 				{
 					$tenant_data=$this->bocommon->read_single_tenant($extra['tenant_id']);
 					$location_data['tenant_id']		= $extra['tenant_id'];
-					$location_data['contact_phone']	= $tenant_data['contact_phone'];
+					$location_data['contact_phone']	= $extra['contact_phone']?$extra['contact_phone']:$tenant_data['contact_phone'];
 					$location_data['last_name']		= $tenant_data['last_name'];
 					$location_data['first_name']	= $tenant_data['first_name'];
 				}
