@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage helpdesk
- 	* @version $Id: class.botts.inc.php,v 1.31 2007/01/26 14:53:46 sigurdne Exp $
+ 	* @version $Id: class.botts.inc.php,v 1.34 2007/05/19 20:52:10 sigurdne Exp $
 	*/
 
 	/**
@@ -80,6 +80,10 @@
 			$this->config->read_repository();
 			$this->dateformat = $GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'];
 
+			$this->vfs 			= CreateObject('phpgwapi.vfs');
+			$this->rootdir 		= $this->vfs->basedir;
+			$this->fakebase 	= $this->vfs->fakebase;
+
 			if ($session)
 			{
 				$this->read_sessiondata();
@@ -119,11 +123,11 @@
 			{
 				$this->user_filter = $user_filter;
 			}
-			if(array_key_exists('sort',$_POST))
+			if(array_key_exists('sort',$_POST) || array_key_exists('sort',$_GET))
 			{
 				$this->sort = $sort;
 			}
-			if(array_key_exists('order',$_POST))
+			if(array_key_exists('order',$_POST) || array_key_exists('order',$_GET))
 			{
 				$this->order = $order;
 			}
@@ -279,7 +283,7 @@
 					$tickets[$i]['delay']=($tickets[$i]['finnish_date2']-$tickets[$i]['finnish_date'])/(24*3600);
 					$tickets[$i]['finnish_date']=$tickets[$i]['finnish_date2'];
 				}
-				$tickets[$i]['finnish_date'] = (isset($tickets[$i]['finnish_date'])?$GLOBALS['phpgw']->common->show_date($tickets[$i]['finnish_date'],$this->dateformat):'');
+				$tickets[$i]['finnish_date'] = (isset($tickets[$i]['finnish_date']) && $tickets[$i]['finnish_date'] ? $GLOBALS['phpgw']->common->show_date($tickets[$i]['finnish_date'],$this->dateformat):'');
 
 				if ($tickets[$i]['status'] == 'X')
 				{
@@ -314,7 +318,7 @@
 			$ticket['group_lid'] = $GLOBALS['phpgw']->accounts->id2name($ticket['group_id']);
 
 
-			if($ticket['finnish_date2'])
+			if(isset($ticket['finnish_date2']) && $ticket['finnish_date2'])
 			{
 				$ticket['finnish_date']=$ticket['finnish_date2'];
 			}
@@ -393,6 +397,25 @@
 			$ticket['user_lid']=$GLOBALS['phpgw']->accounts->id2name($ticket['user_id']);
 			$ticket['category_name']=ucfirst($this->get_category_name($ticket['cat_id']));
 
+			$this->vfs->override_acl = 1;
+
+			$ticket['files'] = $this->vfs->ls (array(
+			     'string' => $this->fakebase. SEP . 'fmticket' . SEP . $id,
+			     'relatives' => array(RELATIVE_NONE)));
+
+			$this->vfs->override_acl = 0;
+
+			$j	= count($ticket['files']);
+			for ($i=0;$i<$j;$i++)
+			{
+				$ticket['files'][$i]['file_name']=urlencode($ticket['files'][$i]['name']);
+			}
+
+
+			if(!$ticket['files'][0]['file_id'])
+			{
+				unset($ticket['files']);
+			}
 			return $ticket;
 		}
 
@@ -782,5 +805,116 @@
 		{
 			$this->so->delete($id);
 		}
+
+		function create_home_dir($receipt='')
+		{
+			if(!$this->vfs->file_exists(array(
+					'string' => $this->fakebase. SEP . 'fmticket',
+					'relatives' => Array(RELATIVE_NONE)
+				)))
+			{
+				$this->vfs->override_acl = 1;
+
+				if(!$this->vfs->mkdir (array(
+				     'string' => $this->fakebase. SEP . 'fmticket',
+				     'relatives' => array(
+				          RELATIVE_NONE
+				     )
+				)))
+				{
+					$receipt['error'][]=array('msg'=>lang('failed to create directory') . ' :'. $this->fakebase. SEP . 'fmticket');
+				}
+				else
+				{
+					$receipt['message'][]=array('msg'=>lang('directory created') . ' :'. $this->fakebase. SEP. 'fmticket');
+				}
+				$this->vfs->override_acl = 0;
+			}
+
+			return $receipt;
+		}
+
+		function create_document_dir($id='')
+		{
+			if(!$this->vfs->file_exists(array(
+					'string' => $this->fakebase. SEP . 'fmticket',
+					'relatives' => Array(RELATIVE_NONE)
+				)))
+			{
+				$this->vfs->override_acl = 1;
+				if(!$this->vfs->mkdir (array(
+				     'string' => $this->fakebase. SEP . 'fmticket',
+				     'relatives' => array(
+				          RELATIVE_NONE
+				     )
+				)))
+				{
+					$receipt['error'][]=array('msg'=>lang('failed to create directory') . ' :'. $this->fakebase. SEP . 'fmticket');
+				}
+				else
+				{
+					$receipt['message'][]=array('msg'=>lang('directory created') . ' :'. $this->fakebase. SEP . 'fmticket');
+				}
+				$this->vfs->override_acl = 0;
+			}
+
+
+			if(!$this->vfs->file_exists(array(
+					'string' => $this->fakebase. SEP . 'fmticket' .  SEP . $id,
+					'relatives' => Array(RELATIVE_NONE)
+				)))
+			{
+				$this->vfs->override_acl = 1;
+				if(!$this->vfs->mkdir (array(
+				     'string' => $this->fakebase. SEP . 'fmticket' .  SEP . $id,
+				     'relatives' => array(
+				          RELATIVE_NONE
+				     )
+				)))
+				{
+					$receipt['error'][]=array('msg'=>lang('failed to create directory') . ' :'. $this->fakebase. SEP  . 'fmticket' .  SEP . $id);
+				}
+				else
+				{
+					$receipt['message'][]=array('msg'=>lang('directory created') . ' :'. $this->fakebase. SEP . 'fmticket' .  SEP . $id);
+				}
+				$this->vfs->override_acl = 0;
+			}
+
+//_debug_array($receipt);
+			return $receipt;
+		}
+		
+		function delete_file($values,$id='')
+		{
+			for ($i=0;$i<count($values['delete_file']);$i++)
+			{
+				$file = $this->fakebase. SEP . 'fmticket' . SEP . $id . SEP . $values['delete_file'][$i];
+
+				if($this->vfs->file_exists(array(
+					'string' => $file,
+					'relatives' => Array(RELATIVE_NONE)
+				)))
+				{
+					$this->vfs->override_acl = 1;
+
+					if(!$this->vfs->rm (array(
+						'string' => $file,
+					     'relatives' => array(
+					          RELATIVE_NONE
+					     )
+					)))
+					{
+						$receipt['error'][]=array('msg'=>lang('failed to delete file') . ' :'. $this->fakebase. SEP . 'fmticket' . SEP . $id . SEP .$values['delete_file'][$i]);
+					}
+					else
+					{
+						$receipt['message'][]=array('msg'=>lang('file deleted') . ' :'. $this->fakebase. SEP . 'fmticket' . SEP . $id . SEP . $values['delete_file'][$i]);
+					}
+					$this->vfs->override_acl = 0;
+				}
+			}
+			return $receipt;
+		}
 	}
 ?>
