@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage project
- 	* @version $Id: class.boworkorder.inc.php,v 1.21 2007/01/26 14:53:46 sigurdne Exp $
+ 	* @version $Id: class.boworkorder.inc.php,v 1.22 2007/02/20 22:22:20 sigurdne Exp $
 	*/
 
 	/**
@@ -192,7 +192,6 @@
 
 		function select_branch_p_list($project_id='')
 		{
-
 			$selected		= $this->so->branch_p_list($project_id);
 			$branch_entries	= $this->so->select_branch_list();
 
@@ -212,18 +211,9 @@
 				$j++;
 			}
 
-			for ($i=0;$i<count($branch_list);$i++)
-			{
-				if ($branch_list[$i]['selected'] != 'selected')
-				{
-					unset($branch_list[$i]['selected']);
-				}
-			}
-
 			return $branch_list;
 		}
 
-
 		function select_key_location_list($selected='')
 		{
 			$key_location_entries= $this->so->select_key_location_list();
