@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage core
- 	* @version $Id: class.menu.inc.php,v 1.37 2007/01/26 14:53:46 sigurdne Exp $
+ 	* @version $Id: class.menu.inc.php,v 1.38 2007/03/23 09:35:57 sigurdne Exp $
 	*/
 
 	/**
@@ -55,7 +55,7 @@
 			$sub = $this->sub;
 			if(!$this->query)
 			{
-//				$menu = $GLOBALS['phpgw']->session->appsession('menu',substr(md5($currentapp.$sub . '_' . $page . '_' . $page_2),-20));
+				$menu = $GLOBALS['phpgw']->session->appsession('menu',substr(md5($currentapp.$sub . '_' . $page . '_' . $page_2),-20));
 			}
 //_debug_array($page);
 			if(!isset($menu) || !$menu)
