@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage project
- 	* @version $Id: class.soproject.inc.php,v 1.41 2007/02/20 22:22:20 sigurdne Exp $
+ 	* @version $Id: class.soproject.inc.php,v 1.43 2007/03/21 22:16:12 sigurdne Exp $
 	*/
 
 	/**
@@ -47,13 +47,12 @@
 			$this->left_join	= $this->bocommon->left_join;
 			$this->like			= $this->bocommon->like;
 
-			$this->grants 	= $GLOBALS['phpgw']->session->appsession('grants_project',$this->currentapp);
-
-			if(!$this->grants)
+		//	$this->grants 	= $GLOBALS['phpgw']->session->appsession('grants_project',$this->currentapp);
+		//	if(!$this->grants)
 			{
 				$this->acl 		= CreateObject('phpgwapi.acl');
 				$this->grants		= $this->acl->get_grants($this->currentapp,'.project');
-				$GLOBALS['phpgw']->session->appsession('grants_project',$this->currentapp,$this->grants);
+		//		$GLOBALS['phpgw']->session->appsession('grants_project',$this->currentapp,$this->grants);
 			}
 		}
 
@@ -434,18 +433,20 @@
 		function project_workorder_data($project_id = '')
 		{
 			$budget = array();
-			$this->db->query("SELECT act_mtrl_cost, act_vendor_cost, budget, id as workorder_id, vendor_id, calculation,rig_addition,addition,deviation,charge_tenant from fm_workorder where project_id='$project_id'");
+			$this->db->query("SELECT act_mtrl_cost, act_vendor_cost, budget, fm_workorder.id as workorder_id, vendor_id, calculation,rig_addition,addition,deviation,charge_tenant,fm_workorder_status.descr as status"
+			." FROM fm_workorder $this->join fm_workorder_status ON fm_workorder.status = fm_workorder_status.id WHERE project_id='$project_id'");
 			while ($this->db->next_record())
 			{
 				$budget[] = array(
 					'workorder_id'		=> $this->db->f('workorder_id'),
-					'budget'		=> $this->db->f('budget'),
-					'deviation'		=> $this->db->f('deviation'),
+					'budget'			=> $this->db->f('budget'),
+					'deviation'			=> $this->db->f('deviation'),
 					'calculation'		=> ($this->db->f('calculation')*(1+$this->db->f('addition')/100))+$this->db->f('rig_addition'),
-					'vendor_id'		=> $this->db->f('vendor_id'),
+					'vendor_id'			=> $this->db->f('vendor_id'),
 					'act_mtrl_cost'		=> $this->db->f('act_mtrl_cost'),
 					'act_vendor_cost'	=> $this->db->f('act_vendor_cost'),
-					'charge_tenant'		=> $this->db->f('charge_tenant')
+					'charge_tenant'		=> $this->db->f('charge_tenant'),
+					'status'			=> $this->db->f('status')
 					);
 			}
 			return $budget;
