@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage helpdesk
- 	* @version $Id: class.sotts.inc.php,v 1.23 2007/02/20 22:22:20 sigurdne Exp $
+ 	* @version $Id: class.sotts.inc.php,v 1.24 2007/04/24 08:04:10 sigurdne Exp $
 	*/
 
 	/**
@@ -34,7 +34,6 @@
 
 	class property_sotts
 	{
-
 		function property_sotts()
 		{
 			$this->currentapp	= $GLOBALS['phpgw_info']['flags']['currentapp'];
@@ -59,39 +58,22 @@
 
 		function read($data)
 		{
-
 			if(is_array($data))
 			{
-				if ($data['start'])
-				{
-					$start=$data['start'];
-				}
-				else
-				{
-					$start=0;
-				}
-				if ($data['filter'])
-				{
-					$filter=$data['filter'];
-				}
-				else
-				{
-					$filter='open';
-				}
-		//		$filter	= (isset($data['filter'])?$data['filter']:'open');
+				$start	= (isset($data['start']) && $data['start'] ? $data['start']:0);
+				$filter	= (isset($data['filter']) && $data['filter'] ? $data['filter']:'open');
 				$user_filter= (isset($data['user_filter'])?$data['user_filter']:'');
 				$query = (isset($data['query'])?$data['query']:'');
-				$sort = (isset($data['sort'])?$data['sort']:'DESC');
+				$sort = (isset($data['sort']) && $data['sort'] ? $data['sort']:'DESC');
 				$order = (isset($data['order'])?$data['order']:'');
-				$cat_id = (isset($data['cat_id'])?$data['cat_id']:0);
-				$district_id = (isset($data['district_id'])?$data['district_id']:0);
+				$cat_id = (isset($data['cat_id']) && $data['cat_id'] ? $data['cat_id']:0);
+				$district_id = (isset($data['district_id']) && $data['district_id'] ? $data['district_id']:0);
 				$allrows = (isset($data['allrows'])?$data['allrows']:'');
 				$start_date = (isset($data['start_date'])?$data['start_date']:'');
 				$end_date = (isset($data['end_date'])?$data['end_date']:'');
 				$external = (isset($data['external'])?$data['external']:'');
 			}
 
-
 			$this->grants 	= $GLOBALS['phpgw']->session->appsession('grants_ticket',$this->currentapp);
 
 			if(!$this->grants)
