@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage project
- 	* @version $Id: class.soworkorder.inc.php,v 1.28 2007/01/26 14:53:47 sigurdne Exp $
+ 	* @version $Id: class.soworkorder.inc.php,v 1.29 2007/03/21 22:16:12 sigurdne Exp $
 	*/
 
 	/**
@@ -48,15 +48,12 @@
 
 			$this->like			= $this->bocommon->like;
 
-			$this->grants 		= $GLOBALS['phpgw']->session->appsession('grants_project',$this->currentapp);
-
-
-
-			if(!$this->grants)
+		//	$this->grants 		= $GLOBALS['phpgw']->session->appsession('grants_project',$this->currentapp);
+		//	if(!$this->grants)
 			{
 				$this->acl 		= CreateObject('phpgwapi.acl');
 				$this->grants		= $this->acl->get_grants($this->currentapp,'.project');
-				$GLOBALS['phpgw']->session->appsession('grants_project',$this->currentapp,$this->grants);
+		//		$GLOBALS['phpgw']->session->appsession('grants_project',$this->currentapp,$this->grants);
 			}
 		}
 
