@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage document
- 	* @version $Id: class.uidocument.inc.php,v 1.20 2007/01/26 14:53:47 sigurdne Exp $
+ 	* @version $Id: class.uidocument.inc.php,v 1.22 2007/05/21 07:41:42 sigurdne Exp $
 	*/
 
 	/**
@@ -655,19 +655,20 @@
 				)))
 			{
 
-				$size		= $this->bo->vfs->get_size(array(
-							'string' => $file,
-							'relatives' => Array(RELATIVE_NONE),
-							'checksubdirs' => True));
+				$ls_array = $this->bo->vfs->ls (array (
+						'string'	=>  $file,
+						'relatives' => Array(RELATIVE_NONE),
+						'checksubdirs'	=> False,
+						'nofiles'	=> True
+					)
+				);
 
 				$document= $this->bo->vfs->read(array(
 					'string' => $file,
 					'relatives' => Array(RELATIVE_NONE)));
 
-				$filename 	= basename($values['document_name']);
-				$filetype = array_pop(explode('.', basename($file)));
 				$browser = CreateObject('phpgwapi.browser');
-				$browser->content_header($filename,$filetype,$size);
+				$browser->content_header($ls_array[0]['name'],$ls_array[0]['mime_type'],$ls_array[0]['size']);
 
 				echo $document;
 			}
@@ -817,11 +818,12 @@
 
 				$values['document_id'] = $document_id;
 
-
 				if(!$receipt['error'])
 				{
 					if($values['document_name'] && !$values['link'])
 					{
+						$this->bo->vfs->override_acl = 1;
+
 						if(!$this->bo->vfs->cp (array (
 							'from'		=> $_FILES['document_file']['tmp_name'],
 							'to'		=> $to_file,
@@ -829,6 +831,7 @@
 						{
 							$receipt['error'][]=array('msg'=>lang('Failed to upload file !'));
 						}
+						$this->bo->vfs->override_acl = 0;
 					}
 
 					if(!$receipt['error'])
