@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage entity
- 	* @version $Id: class.uientity.inc.php,v 1.41 2007/02/14 14:22:22 sigurdne Exp $
+ 	* @version $Id: class.uientity.inc.php,v 1.44 2007/05/20 12:59:12 sigurdne Exp $
 	*/
 
 	/**
@@ -252,22 +252,22 @@
 				'relatives' => Array(RELATIVE_NONE)
 				)))
 			{
-				$size		= $this->bo->vfs->get_size(array(
-							'string' => $file,
-							'relatives' => Array(RELATIVE_NONE),
-							'checksubdirs' => True));
+				$ls_array = $this->bo->vfs->ls (array (
+						'string'	=>  $file,
+						'relatives' => Array(RELATIVE_NONE),
+						'checksubdirs'	=> False,
+						'nofiles'	=> True
+					)
+				);
 
 				$document= $this->bo->vfs->read(array(
 					'string' => $file,
 					'relatives' => Array(RELATIVE_NONE)));
 
-				$filename 	= basename($values['document_name']);
-				$filetype = array_pop(explode('.', basename($file)));
 				$browser = CreateObject('phpgwapi.browser');
-				$browser->content_header($filename,$filetype,$size);
+				$browser->content_header($ls_array[0]['name'],$ls_array[0]['mime_type'],$ls_array[0]['size']);
 
 				echo $document;
-
 			}
 		}
 
@@ -542,7 +542,6 @@
 				'lang_user_statustext'		=> lang('Select the user. To do not use a category select NO USER'),
 				'select_user_name'			=> 'filter',
 				'lang_no_user'				=> lang('No user'),
-				'user_list'					=> $this->bocommon->get_user_list_right2($group_filters,4,$this->filter,$this->acl_location,array('all'),$default='all'),
 
 				'lang_filter_statustext'		=> lang('Select the filter. To show all entries select SHOW ALL'),
 				'lang_searchfield_statustext'	=> lang('Enter the search string. To show all entries, empty this field and press the SUBMIT button again'),
@@ -554,7 +553,6 @@
 				'table_add'					=> $table_add
 			);
 
-
 			if(!$this->entity_id || !$this->cat_id)
 			{
 				$GLOBALS['phpgw']->xslttpl->add_file(array('cat_filter'));
@@ -563,12 +561,12 @@
 
 				$GLOBALS['phpgw_info']['flags']['app_header'] = lang($this->currentapp) . ' - ' . $appname;
 				$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('empty' => $data));
-			//	$GLOBALS['phpgw']->xslttpl->pp();
 			}
 			else
 			{
+				$data['user_list']	= $this->bocommon->get_user_list_right2($group_filters,4,$this->filter,$this->acl_location,array('all'),$default='all');
+				$GLOBALS['phpgw']->js->set_onload('document.search.query.focus();');
 				$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('list' => $data));
-			//	$GLOBALS['phpgw']->xslttpl->pp();
 				$this->save_sessiondata();
 			}
 		}
