@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage location
- 	* @version $Id: class.uilocation.inc.php,v 1.50 2007/01/26 14:53:47 sigurdne Exp $
+ 	* @version $Id: class.uilocation.inc.php,v 1.52 2007/03/29 08:48:58 sigurdne Exp $
 	*/
 
 	/**
@@ -146,6 +146,7 @@
 								);
 			}
 
+			$GLOBALS['phpgw_info']['apps']['manual']['section'] = 'location';
 			$GLOBALS['phpgw']->xslttpl->add_file(array('location',
 										'menu',
 										'nextmatchs',
@@ -157,6 +158,7 @@
 			$lookup_tenant 	= get_var('lookup_tenant',array('POST','GET'));
 
 			$GLOBALS['phpgw']->js->validate_file('overlib','overlib',$this->currentapp);
+			$GLOBALS['phpgw']->js->set_onload('document.search.query.focus();');
 
 			if(!$type_id)
 			{
