@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage project
- 	* @version $Id: class.uiproject.inc.php,v 1.51 2007/02/20 22:22:20 sigurdne Exp $
+ 	* @version $Id: class.uiproject.inc.php,v 1.56 2007/03/23 16:02:48 sigurdne Exp $
 	*/
 
 	/**
@@ -426,7 +426,7 @@
 				'lang_user_statustext'		=> lang('Select the user the project belongs to. To do not use a category select NO USER'),
 				'select_user_name'		=> 'filter',
 				'lang_no_user'			=> lang('No user'),
-				'user_list'			=> $this->bocommon->get_user_list_right2('filter',4,$this->filter,$this->acl_location),
+				'user_list'			=> $this->bocommon->get_user_list_right2('filter',2,$this->filter,$this->acl_location),
 
 				'lang_searchfield_statustext'	=> lang('Enter the search string. To show all entries, empty this field and press the SUBMIT button again'),
 				'lang_searchbutton_statustext'	=> lang('Submit the search string'),
@@ -523,7 +523,7 @@
 				$receipt = $this->bo->add_request($add_request,$id);
 			}
 
-			if($_POST && !$bypass)
+			if($_POST && !$bypass && isset($insert_record) && is_array($insert_record))
 			{
 				for ($i=0; $i<count($insert_record['location']); $i++)
 				{
@@ -811,7 +811,8 @@
 				'lang_workorder_id'	=> lang('Workorder'),
 				'lang_budget'		=> lang('Budget'),
 				'lang_calculation'	=> lang('Calculation'),
-				'lang_vendor'		=> lang('Vendor')
+				'lang_vendor'		=> lang('Vendor'),
+				'lang_status'		=> lang('status')
 			);
 
 			if ($id)
@@ -944,8 +945,22 @@
 				}
 			}
 
+			$GLOBALS['phpgw']->js->validate_file('tabs', 'tabs');
+
+			if(!is_object($GLOBALS['phpgw']->css))
+			{
+				$GLOBALS['phpgw']->css = createObject('phpgwapi.css');
+			}
+			$GLOBALS['phpgw']->css->validate_file('tabs','phpgwapi');
+
 			$data = array
 			(
+				'lang_general' 					=> lang('General'),
+				'lang_location' 				=> lang('location'),
+				'lang_coordination' 			=> lang('Coordination'),
+				'lang_time_and_budget' 			=> lang('Time and budget'),
+				'lang_extra' 					=> lang('Extra'),
+				
 				'msgbox_data'					=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
 
 				'value_origin'					=> isset($values['origin']) ? $values['origin'] : '',
