@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage agreement
- 	* @version $Id: class.uis_agreement.inc.php,v 1.39 2007/01/26 14:53:47 sigurdne Exp $
+ 	* @version $Id: class.uis_agreement.inc.php,v 1.40 2007/05/21 07:41:42 sigurdne Exp $
 	*/
 
 	/**
@@ -180,19 +180,20 @@
 				'relatives' => Array(RELATIVE_NONE)
 				)))
 			{
-				$size		= $this->bo->vfs->get_size(array(
-							'string' => $file,
-							'relatives' => Array(RELATIVE_NONE),
-							'checksubdirs' => True));
+				$ls_array = $this->bo->vfs->ls (array (
+						'string'	=>  $file,
+						'relatives' => Array(RELATIVE_NONE),
+						'checksubdirs'	=> False,
+						'nofiles'	=> True
+					)
+				);
 
 				$document= $this->bo->vfs->read(array(
 					'string' => $file,
 					'relatives' => Array(RELATIVE_NONE)));
 
-				$filename 	= basename($values['document_name']);
-				$filetype = array_pop(explode('.', basename($file)));
 				$browser = CreateObject('phpgwapi.browser');
-				$browser->content_header($filename,$filetype,$size);
+				$browser->content_header($ls_array[0]['name'],$ls_array[0]['mime_type'],$ls_array[0]['size']);
 
 				echo $document;
 			}
