@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage helpdesk
- 	* @version $Id: class.uitts.inc.php,v 1.55 2007/02/20 22:22:20 sigurdne Exp $
+ 	* @version $Id: class.uitts.inc.php,v 1.58 2007/05/20 12:59:12 sigurdne Exp $
 	*/
 
 	/**
@@ -44,7 +44,8 @@
 			'add2'		=> True,
 			'delete'	=> True,
 			'excel'		=> True,
-			'excel2'	=> True
+			'excel2'	=> True,
+			'view_file'	=> True
 		);
 
 		function property_uitts()
@@ -86,6 +87,7 @@
 			$this->allrows				= $this->bo->allrows;
 			$this->start_date			= $this->bo->start_date;
 			$this->end_date				= $this->bo->end_date;
+			$this->fakebase 			= $this->bo->fakebase;
 
 			$this->menu->sub			='ticket';
 		}
@@ -207,6 +209,8 @@
 				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> $this->currentapp.'.uilocation.stop', 'perm'=> 1, 'acl_location'=> $this->acl_location));
 			}
 
+			$GLOBALS['phpgw']->js->set_onload('document.search.query.focus();');
+
 			if(get_var('edit_status',array('POST','GET')))
 			{
 				if(!$this->acl_edit)
@@ -1022,7 +1026,39 @@
 
 				if(!isset($receipt['error']))
 				{
+					$receipt	= $this->bo->create_home_dir($receipt);
+
 					$receipt = $this->bo->add($values);
+
+					$values['file_name']=str_replace(' ','_',$_FILES['file']['name']);
+
+					if($values['file_name'])
+					{
+						$to_file = $this->fakebase. SEP . 'fmticket' . SEP . $receipt['id'] . SEP . $values['file_name'];
+	
+						if($this->bo->vfs->file_exists(array(
+								'string' => $to_file,
+								'relatives' => Array(RELATIVE_NONE)
+							)))
+						{
+							$receipt['error'][]=array('msg'=>lang('This file already exists !'));
+						}
+						else
+						{
+							$this->bo->create_document_dir($receipt['id']);
+							$this->bo->vfs->override_acl = 1;
+
+							if(!$this->bo->vfs->cp (array (
+								'from'	=> $_FILES['file']['tmp_name'],
+								'to'	=> $to_file,
+								'relatives'	=> array (RELATIVE_NONE|VFS_REAL, RELATIVE_ALL))))
+							{
+								$receipt['error'][]=array('msg'=>lang('Failed to upload file !'));
+							}
+							$this->bo->vfs->override_acl = 0;
+						}
+					}
+
 					$GLOBALS['phpgw']->session->appsession('receipt',$this->currentapp,$receipt);
 					$GLOBALS['phpgw']->session->appsession('session_data','fm_tts','');
 					$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> $this->currentapp.'.uitts.index'));
@@ -1106,7 +1142,6 @@
 					break;
 			}
 
-
 			$msgbox_data = (isset($receipt)?$this->bocommon->msgbox_data($receipt):'');
 
 			$GLOBALS['phpgw']->js->validate_file('dateformat','dateformat',$this->currentapp);
@@ -1165,6 +1200,7 @@
 				'lang_mailnotification'			=> lang('Send e-mail'),
 				'lang_mailnotification_statustext'	=> lang('Choose to send mailnotification'),
 				'pref_send_mail'			=> (isset($GLOBALS['phpgw_info']['user']['preferences'][$this->currentapp]['tts_user_mailnotification'])?$GLOBALS['phpgw_info']['user']['preferences'][$this->currentapp]['tts_user_mailnotification']:''),
+				'fileupload'				=> (isset($this->bo->config->config_data['fmttsfileupload'])?$this->bo->config->config_data['fmttsfileupload']:''),
 			);
 
 //_debug_array($data);
@@ -1436,6 +1472,39 @@
 				$so2	= CreateObject($this->currentapp.'.sotts2');
 				$so2->acl_location	= $this->acl_location;				
 				$receipt = $so2->update_ticket($values,$id);
+				if(isset($values['delete_file']) && is_array($values['delete_file']))
+				{
+					$this->bo->delete_file($values,$id);
+				}
+
+				$values['file_name']=str_replace(' ','_',$_FILES['file']['name']);
+
+				if($values['file_name'])
+				{
+					$to_file = $this->fakebase. SEP . 'fmticket' . SEP . $id . SEP . $values['file_name'];
+	
+					if($this->bo->vfs->file_exists(array(
+							'string' => $to_file,
+							'relatives' => Array(RELATIVE_NONE)
+						)))
+					{
+						$receipt['error'][]=array('msg'=>lang('This file already exists !'));
+					}
+					else
+					{
+						$this->bo->create_document_dir($id);
+						$this->bo->vfs->override_acl = 1;
+
+						if(!$this->bo->vfs->cp (array (
+							'from'	=> $_FILES['file']['tmp_name'],
+							'to'	=> $to_file,
+							'relatives'	=> array (RELATIVE_NONE|VFS_REAL, RELATIVE_ALL))))
+						{
+							$receipt['error'][]=array('msg'=>lang('Failed to upload file !'));
+						}
+						$this->bo->vfs->override_acl = 0;
+					}
+				}
 			}
 
 			$ticket = $this->bo->read_single($id);
@@ -1607,6 +1676,12 @@
 
 			$GLOBALS['phpgw']->js->validate_file('dateformat','dateformat',$this->currentapp);
 
+			$link_file_data = array
+			(
+				'menuaction'	=> $this->currentapp.'.uitts.view_file',
+				'id'		=> $id
+			);
+
 			$data = array
 			(
 				'value_origin'				=> (isset($ticket['origin'])?$ticket['origin']:''),
@@ -1708,6 +1783,18 @@
 				'lang_mailnotification'			=> lang('Send e-mail'),
 				'lang_mailnotification_statustext'	=> lang('Choose to send mailnotification'),
 				'pref_send_mail'			=> (isset($GLOBALS['phpgw_info']['user']['preferences'][$this->currentapp]['tts_user_mailnotification'])?$GLOBALS['phpgw_info']['user']['preferences'][$this->currentapp]['tts_user_mailnotification']:''),
+				'fileupload'				=> (isset($this->bo->config->config_data['fmttsfileupload'])?$this->bo->config->config_data['fmttsfileupload']:''),
+				'link_view_file'				=> $GLOBALS['phpgw']->link('/index.php',$link_file_data),
+				'link_to_files'					=> (isset($this->bo->config->config_data['files_url'])?$this->bo->config->config_data['files_url']:''),
+				'files'							=> $ticket['files'],
+				'lang_files'					=> lang('files'),
+				'lang_filename'					=> lang('Filename'),
+				'lang_delete_file'				=> lang('Delete file'),
+				'lang_view_file_statustext'		=> lang('Klick to view file'),
+				'lang_delete_file_statustext'	=> lang('Check to delete file'),
+				'lang_upload_file'				=> lang('Upload file'),
+				'lang_file_statustext'			=> lang('Select file to upload'),
+
 			);
 //_debug_array($data);
 			$appname					= lang('helpdesk');
@@ -1951,5 +2038,47 @@
 			$GLOBALS['phpgw_info']['flags']['app_header'] = lang($this->currentapp) . ' - ' . $appname . ': ' . $function_msg;
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('view2' => $data));
 		}
+
+		function view_file()
+		{
+			$GLOBALS['phpgw_info']['flags'][noheader] = True;
+			$GLOBALS['phpgw_info']['flags'][nofooter] = True;
+			$GLOBALS['phpgw_info']['flags']['xslt_app'] = False;
+
+			if(!$this->acl_read)
+			{
+				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> $this->currentapp.'.uilocation.stop', 'perm'=>1, 'acl_location'=> $this->acl_location));
+			}
+
+			$file_name	= urldecode(get_var('file_name',array('POST','GET')));
+			$id 		= get_var('id',array('POST','GET'));
+
+			$file = $this->fakebase. SEP . 'fmticket' . SEP . $id . SEP . $file_name;
+
+			if($this->bo->vfs->file_exists(array(
+				'string' => $file,
+				'relatives' => Array(RELATIVE_NONE)
+				)))
+			{
+
+				$ls_array = $this->bo->vfs->ls (array (
+						'string'	=>  $file,
+						'relatives' => Array(RELATIVE_NONE),
+						'checksubdirs'	=> False,
+						'nofiles'	=> True
+					)
+				);
+
+				$document= $this->bo->vfs->read(array(
+					'string' => $file,
+					'relatives' => Array(RELATIVE_NONE)));
+
+				$browser = CreateObject('phpgwapi.browser');
+				$browser->content_header($ls_array[0]['name'],$ls_array[0]['mime_type'],$ls_array[0]['size']);
+
+				echo $document;
+
+			}
+		}
 	}
 ?>
