@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage custom
- 	* @version $Id: synkroniser_med_boei.php,v 1.1 2007/02/27 10:11:29 sigurdne Exp $
+ 	* @version $Id: synkroniser_med_boei.php,v 1.5 2007/03/23 12:05:41 sigurdne Exp $
 	*/
 
 	/**
@@ -40,27 +40,34 @@
 		{
 			$this->currentapp		= $GLOBALS['phpgw_info']['flags']['currentapp'];
 			$this->bocommon			= CreateObject($this->currentapp.'.bocommon');
-			$this->db				= $this->bocommon->new_db();
+			$this->db     			= & $GLOBALS['phpgw']->db;
+			$this->join				= $this->db->join;
+			$this->like				= $this->db->like;
+			$this->left_join 		= " LEFT JOIN ";
 
-			$this->join				= $this->bocommon->join;
-			$this->left_join		= $this->bocommon->left_join;
-			$this->like				= $this->bocommon->like;
-
-			$this->db_boei           	= CreateObject($this->currentapp.'.db_mssql');
-			$this->db_boei->Host     	= $GLOBALS['external_db']['boei']['db_host'];
-			$this->db_boei->Type     	= $GLOBALS['external_db']['boei']['db_type'];
-			$this->db_boei->Database 	= $GLOBALS['external_db']['boei']['db_name'];
-			$this->db_boei->User     	= $GLOBALS['external_db']['boei']['db_user'];
-			$this->db_boei->Password 	= $GLOBALS['external_db']['boei']['db_pass'];
-			$this->db_boei->Halt_On_Error 	= 'yes';
-
-			$this->db_boei2           	= CreateObject($this->currentapp.'.db_mssql');
-			$this->db_boei2->Host     	= $GLOBALS['external_db']['boei']['db_host'];
-			$this->db_boei2->Type     	= $GLOBALS['external_db']['boei']['db_type'];
-			$this->db_boei2->Database 	= $GLOBALS['external_db']['boei']['db_name'];
-			$this->db_boei2->User     	= $GLOBALS['external_db']['boei']['db_user'];
-			$this->db_boei2->Password 	= $GLOBALS['external_db']['boei']['db_pass'];
-			$this->db_boei2->Halt_On_Error 	= 'yes';
+			if(isset($this->db->adodb) && $this->db->adodb)
+			{
+				$this->db_boei           	= CreateObject('phpgwapi.db',false,$GLOBALS['external_db']['boei']['db_type']);
+				$this->db_boei->Host     	= $GLOBALS['external_db']['boei']['db_host'];
+				$this->db_boei->Type     	= $GLOBALS['external_db']['boei']['db_type'];
+				$this->db_boei->Database 	= $GLOBALS['external_db']['boei']['db_name'];
+				$this->db_boei->User     	= $GLOBALS['external_db']['boei']['db_user'];
+				$this->db_boei->Password 	= $GLOBALS['external_db']['boei']['db_pass'];
+				$this->db_boei->Halt_On_Error 	= 'yes';			
+				$this->db_boei->connect();
+			}
+			else
+			{
+				$this->db_boei           	= CreateObject($this->currentapp.'.db_mssql');
+				$this->db_boei->Host     	= $GLOBALS['external_db']['boei']['db_host'];
+				$this->db_boei->Type     	= $GLOBALS['external_db']['boei']['db_type'];
+				$this->db_boei->Database 	= $GLOBALS['external_db']['boei']['db_name'];
+				$this->db_boei->User     	= $GLOBALS['external_db']['boei']['db_user'];
+				$this->db_boei->Password 	= $GLOBALS['external_db']['boei']['db_pass'];
+				$this->db_boei->Halt_On_Error 	= 'yes';
+			}
+			
+			$this->db_boei2 = clone($this->db_boei);
 		}
 
 		function pre_run($data='')
@@ -99,7 +106,7 @@
 
 			if(!$execute)
 			{
-				$lang_confirm_msg 	= 'Vil du virkelig utfre denne operasjonen';
+				$lang_confirm_msg 	= lang('do you want to perform this action');
 			}
 
 			$lang_yes			= lang('yes');
@@ -133,6 +140,7 @@
 
 		function execute($cron='')
 		{
+			set_time_limit(120);
 			$receipt = $this->legg_til_eier_phpgw();
 			$this->cron_log($receipt,$cron);
 			$receipt = $this->legg_til_gateadresse_phpgw();
@@ -204,9 +212,8 @@
 				 'category' 	=> $category,
 				 );			
 			}
-			
-			$this->db->transaction_begin();
-			$this->db_boei->transaction_begin();
+	//		$this->db->transaction_begin();
+	//		$this->db_boei->transaction_begin();
 
 			for ($i=0; $i<count($owner); $i++)
 			{
@@ -233,7 +240,16 @@
 				{
 					$category = $this->db_boei->f('category');
 				}
-				$owner[]= array (
+				$owner_utf[]= array (
+				 'id' 		=> $this->db_boei->f('id'),
+				 'org_name' 	=> $this->db->db_addslashes($this->bocommon->ascii2utf($this->db_boei->f('org_name'))),
+				 'remark' 	=> $this->db->db_addslashes($this->bocommon->ascii2utf($this->db_boei->f('org_name'))),
+				 'category' 	=> $category,
+				 'entry_date'	=> time(),
+				 'owner_id'		=> 6
+				 );
+
+				$owner_latin[]= array (
 				 'id' 		=> $this->db_boei->f('id'),
 				 'org_name' 	=> $this->db->db_addslashes($this->db_boei->f('org_name')),
 				 'remark' 	=> $this->db->db_addslashes($this->db_boei->f('org_name')),
@@ -241,23 +257,25 @@
 				 'entry_date'	=> time(),
 				 'owner_id'		=> 6
 				 );
-			}
-			$this->db->transaction_begin();
-			$this->db_boei->transaction_begin();
 
-			for ($i=0; $i<count($owner); $i++)
+			}
+
+			for ($i=0; $i<count($owner_utf); $i++)
 			{
-				$sql2 = "INSERT INTO fm_owner (id,org_name,remark,category,entry_date,owner_id)"
-					. "VALUES (" . $this->bocommon->validate_db_insert($owner[$i]) . ")";
+				$sql2_utf = "INSERT INTO fm_owner (id,org_name,remark,category,entry_date,owner_id)"
+					. "VALUES (" . $this->bocommon->validate_db_insert($owner_utf[$i]) . ")";
 
-				$this->db->query($sql2,__LINE__,__FILE__);
-				$this->db_boei->query($sql2,__LINE__,__FILE__);
+				$sql2_latin = "INSERT INTO fm_owner (id,org_name,remark,category,entry_date,owner_id)"
+					. "VALUES (" . $this->bocommon->validate_db_insert($owner_latin[$i]) . ")";
 
-				$owner_msg[]=$owner[$i]['org_name'];
+				$this->db->query($sql2_utf,__LINE__,__FILE__);
+				$this->db_boei->query($sql2_latin,__LINE__,__FILE__);
+
+				$owner_msg[]=$owner_utf[$i]['org_name'];
 			}
 
-			$this->db->transaction_commit();
-			$this->db_boei->transaction_commit();
+	//		$this->db->transaction_commit();
+	//		$this->db_boei->transaction_commit();
 
 			$msg = count($owner) . ' eier er lagt til: ' . @implode(",", $owner_msg);
 			$this->receipt['message'][]=array('msg'=> $msg);
@@ -284,20 +302,24 @@
 				 );
 
 			}
-
 			$this->db->transaction_begin();
 			$this->db_boei->transaction_begin();
 
 			for ($i=0; $i<count($gate); $i++)
 			{
 
-				$sql2 = "INSERT INTO fm_streetaddress (id,descr)"
+				$sql = "DELETE from fm_streetaddress WHERE id = " . (int)$gate[$i]['id'];
+				$sql2_latin = "INSERT INTO fm_streetaddress (id,descr)"
 					. " VALUES (" . $gate[$i]['id'] . ", '". $gate[$i]['descr']. "')";
 
-				$this->db->query($sql2,__LINE__,__FILE__);
-				$this->db_boei->query($sql2,__LINE__,__FILE__);
+				$sql2_utf = "INSERT INTO fm_streetaddress (id,descr)"
+					. " VALUES (" . $gate[$i]['id'] . ", '". $this->bocommon->ascii2utf($gate[$i]['descr']). "')";
 
-				$gate_msg[]=$gate[$i]['descr'];
+				$this->db->query($sql,__LINE__,__FILE__);
+				$this->db_boei->query($sql,__LINE__,__FILE__);
+				$this->db->query($sql2_utf,__LINE__,__FILE__);
+				$this->db_boei->query($sql2_latin,__LINE__,__FILE__);
+				$gate_msg[]=$this->bocommon->ascii2utf($gate[$i]['descr']);
 			}
 
 			$this->db->transaction_commit();
@@ -321,7 +343,15 @@
 			$this->db_boei->query($sql,__LINE__,__FILE__);
 			while ($this->db_boei->next_record())
 			{
-				$objekt[]= array (
+				$objekt_utf[]= array (
+				 'location_code' 	=> $this->db_boei->f('objekt_id'),
+				 'loc1' 			=> $this->db_boei->f('objekt_id'),
+				 'loc1_name' 		=> $this->bocommon->ascii2utf($this->db_boei->f('navn')),
+				 'part_of_town_id' 	=> $this->db_boei->f('bydel_id'),
+				 'owner_id' 		=> $this->db_boei->f('eier_id'),
+				 'kostra_id' 		=> $this->db_boei->f('tjenestested')
+				 );
+				$objekt_latin[]= array (
 				 'location_code' 	=> $this->db_boei->f('objekt_id'),
 				 'loc1' 			=> $this->db_boei->f('objekt_id'),
 				 'loc1_name' 		=> $this->db_boei->f('navn'),
@@ -332,23 +362,25 @@
 
 			}
 
-			$this->db->transaction_begin();
-			$this->db_boei->transaction_begin();
+	//		$this->db->transaction_begin();
+	//		$this->db_boei->transaction_begin();
 
 			for ($i=0; $i<count($objekt); $i++)
 			{
 
-				$sql2 = "INSERT INTO fm_location1 (location_code, loc1, loc1_name, part_of_town_id, owner_id, kostra_id) "
-					. "VALUES (" . $this->bocommon->validate_db_insert($objekt[$i]) . ")";
+				$sql2_utf = "INSERT INTO fm_location1 (location_code, loc1, loc1_name, part_of_town_id, owner_id, kostra_id) "
+					. "VALUES (" . $this->bocommon->validate_db_insert($objekt_utf[$i]) . ")";
+				$sql2_latin = "INSERT INTO fm_location1 (location_code, loc1, loc1_name, part_of_town_id, owner_id, kostra_id) "
+					. "VALUES (" . $this->bocommon->validate_db_insert($objekt_latin[$i]) . ")";
 
-				$this->db->query($sql2,__LINE__,__FILE__);
-				$this->db_boei->query($sql2,__LINE__,__FILE__);
+				$this->db->query($sql2_utf,__LINE__,__FILE__);
+				$this->db_boei->query($sql2_latin,__LINE__,__FILE__);
 
-				$obj_msg[]=$objekt[$i]['loc1'];
+				$obj_msg[]=$objekt_utf[$i]['loc1'];
 			}
 
-			$this->db->transaction_commit();
-			$this->db_boei->transaction_commit();
+	//		$this->db->transaction_commit();
+	//		$this->db_boei->transaction_commit();
 
 			$msg = count($objekt) . ' Objekt er lagt til: ' . @implode(",", $obj_msg);
 			$this->receipt['message'][]=array('msg'=> $msg);
@@ -368,8 +400,13 @@
 			$this->db_boei->query($sql,__LINE__,__FILE__);
 			while ($this->db_boei->next_record())
 			{
-
-				$bygg[]= array (
+				$bygg_utf[]= array (
+				 'location_code' 	=> $this->db_boei->f('location_code'),
+				 'loc1' 			=> $this->db_boei->f('objekt_id'),
+				 'loc2' 			=> $this->db_boei->f('bygg_id'),
+				 'loc2_name' 		=> $this->bocommon->ascii2utf($this->db_boei->f('byggnavn')),
+				 );
+				$bygg_latin[]= array (
 				 'location_code' 	=> $this->db_boei->f('location_code'),
 				 'loc1' 			=> $this->db_boei->f('objekt_id'),
 				 'loc2' 			=> $this->db_boei->f('bygg_id'),
@@ -377,23 +414,25 @@
 				 );
 			}
 
-			$this->db->transaction_begin();
-			$this->db_boei->transaction_begin();
+		//	$this->db->transaction_begin();
+		//	$this->db_boei->transaction_begin();
 
 			for ($i=0; $i<count($bygg); $i++)
 			{
 
-				$sql2 = "INSERT INTO fm_location2 (location_code, loc1, loc2, loc2_name) "
-					. "VALUES (" . $this->bocommon->validate_db_insert($bygg[$i]) . ")";
+				$sql2_utf = "INSERT INTO fm_location2 (location_code, loc1, loc2, loc2_name) "
+					. "VALUES (" . $this->bocommon->validate_db_insert($bygg_utf[$i]) . ")";
+				$sql2_latin = "INSERT INTO fm_location2 (location_code, loc1, loc2, loc2_name) "
+					. "VALUES (" . $this->bocommon->validate_db_insert($bygg_latin[$i]) . ")";
 
-				$this->db->query($sql2,__LINE__,__FILE__);
-				$this->db_boei->query($sql2,__LINE__,__FILE__);
+				$this->db->query($sql2_utf,__LINE__,__FILE__);
+				$this->db_boei->query($sql2_latin,__LINE__,__FILE__);
 
-				$bygg_msg[]=$bygg[$i]['location_code'];
+				$bygg_msg[]=$bygg_utf[$i]['location_code'];
 			}
 
-			$this->db->transaction_commit();
-			$this->db_boei->transaction_commit();
+		//	$this->db->transaction_commit();
+		//	$this->db_boei->transaction_commit();
 
 			$msg = count($bygg) . ' Bygg er lagt til: ' . @implode(",", $bygg_msg);
 			$this->receipt['message'][]=array('msg'=> $msg);
@@ -417,8 +456,15 @@
 			$this->db_boei->query($sql,__LINE__,__FILE__);
 			while ($this->db_boei->next_record())
 			{
-
-				$seksjon[]= array (
+				$seksjon_utf[]= array (
+				 'location_code' 	=> $this->db_boei->f('location_code'),
+				 'loc1' 			=> $this->db_boei->f('objekt_id'),
+				 'loc2' 			=> $this->db_boei->f('bygg_id'),
+				 'loc3' 			=> $this->db_boei->f('seksjons_id'),
+				 'loc3_name' 		=> $this->bocommon->ascii2utf($this->db_boei->f('beskrivelse')),
+				 'fellesareal' 	=> $this->db_boei->f('totalt_fellesareal')
+				 );
+				$seksjon_latin[]= array (
 				 'location_code' 	=> $this->db_boei->f('location_code'),
 				 'loc1' 			=> $this->db_boei->f('objekt_id'),
 				 'loc2' 			=> $this->db_boei->f('bygg_id'),
@@ -428,23 +474,25 @@
 				 );
 			}
 
-			$this->db->transaction_begin();
-			$this->db_boei->transaction_begin();
+		//	$this->db->transaction_begin();
+		//	$this->db_boei->transaction_begin();
 
 			for ($i=0; $i<count($seksjon); $i++)
 			{
 
-				$sql2 = "INSERT INTO fm_location3 (location_code, loc1, loc2, loc3, loc3_name, fellesareal) "
-					. "VALUES (" . $this->bocommon->validate_db_insert($seksjon[$i]) . ")";
+				$sql2_utf = "INSERT INTO fm_location3 (location_code, loc1, loc2, loc3, loc3_name, fellesareal) "
+					. "VALUES (" . $this->bocommon->validate_db_insert($seksjon_utf[$i]) . ")";
+				$sql2_latin = "INSERT INTO fm_location3 (location_code, loc1, loc2, loc3, loc3_name, fellesareal) "
+					. "VALUES (" . $this->bocommon->validate_db_insert($seksjon_latin[$i]) . ")";
 
-				$this->db->query($sql2,__LINE__,__FILE__);
-				$this->db_boei->query($sql2,__LINE__,__FILE__);
+				$this->db->query($sql2_utf,__LINE__,__FILE__);
+				$this->db_boei->query($sql2_latin,__LINE__,__FILE__);
 
-				$seksjon_msg[]=$seksjon[$i]['location_code'];
+				$seksjon_msg[]=$seksjon_utf[$i]['location_code'];
 			}
 
-			$this->db->transaction_commit();
-			$this->db_boei->transaction_commit();
+		//	$this->db->transaction_commit();
+		//	$this->db_boei->transaction_commit();
 
 			$msg = count($seksjon) . ' Seksjon er lagt til: ' . @implode(",", $seksjon_msg);
 			$this->receipt['message'][]=array('msg'=> $msg);
@@ -470,8 +518,26 @@
 
 			while ($this->db_boei->next_record())
 			{
-
-				$leieobjekt[]= array (
+				$leieobjekt_utf[]= array (
+				 'location_code' 	=> $this->db_boei->f('location_code'),
+				 'loc1' 			=> $this->db_boei->f('objekt_id'),
+				 'loc4' 			=> $this->db_boei->f('leie_id'),
+				 'leieobjekttype_id'=> $this->db_boei->f('leieobjekttype_id'),
+				 'loc2' 			=> $this->db_boei->f('bygg_id'),
+				 'loc3' 			=> $this->db_boei->f('seksjons_id'),
+				 'category' 		=> $this->db_boei->f('formaal_id'),
+				 'street_id'	 	=> $this->db_boei->f('gateadresse_id'),
+				 'street_number' 	=> $this->bocommon->ascii2utf($this->db_boei->f('gatenr')),
+				 'etasje' 			=> $this->bocommon->ascii2utf($this->db_boei->f('etasje')),
+				 'antallrom'	 	=> $this->db_boei->f('antallrom'),
+				 'boareal' 			=> $this->db_boei->f('boareal'),
+				 'livslopsstd' 		=> $this->db_boei->f('livslopsstd'),
+				 'heis' 			=> $this->db_boei->f('heis'),
+				 'driftsstatus_id' 	=> $this->db_boei->f('driftsstatus_id'),
+				 'tenant_id'	 	=> $this->db_boei->f('leietaker_id'),
+				 'beregnet_boa' 	=> $this->db_boei->f('beregnet_boa')
+				 );
+				$leieobjekt_latin[]= array (
 				 'location_code' 	=> $this->db_boei->f('location_code'),
 				 'loc1' 			=> $this->db_boei->f('objekt_id'),
 				 'loc4' 			=> $this->db_boei->f('leie_id'),
@@ -493,24 +559,27 @@
 
 			}
 
-			$this->db->transaction_begin();
-			$this->db_boei->transaction_begin();
+		//	$this->db->transaction_begin();
+		//	$this->db_boei->transaction_begin();
 
 			for ($i=0; $i<count($leieobjekt); $i++)
 			{
 
-				$sql2 = "INSERT INTO fm_location4 (location_code, loc1, loc4, leieobjekttype_id, loc2, loc3, category, street_id, street_number, etasje, antallrom, boareal, livslopsstd, heis, driftsstatus_id,
+				$sql2_utf = "INSERT INTO fm_location4 (location_code, loc1, loc4, leieobjekttype_id, loc2, loc3, category, street_id, street_number, etasje, antallrom, boareal, livslopsstd, heis, driftsstatus_id,
                       tenant_id, beregnet_boa)"
-					. "VALUES (" . $this->bocommon->validate_db_insert($leieobjekt[$i]) . ")";
+					. "VALUES (" . $this->bocommon->validate_db_insert($leieobjekt_utf[$i]) . ")";
+				$sql2_latin = "INSERT INTO fm_location4 (location_code, loc1, loc4, leieobjekttype_id, loc2, loc3, category, street_id, street_number, etasje, antallrom, boareal, livslopsstd, heis, driftsstatus_id,
+                      tenant_id, beregnet_boa)"
+					. "VALUES (" . $this->bocommon->validate_db_insert($leieobjekt_latin[$i]) . ")";
 
-				$this->db->query($sql2,__LINE__,__FILE__);
-				$this->db_boei->query($sql2,__LINE__,__FILE__);
+				$this->db->query($sql2_utf,__LINE__,__FILE__);
+				$this->db_boei->query($sql2_latin,__LINE__,__FILE__);
 
-				$leieobjekt_msg[]=$leieobjekt[$i]['location_code'];
+				$leieobjekt_msg[]=$leieobjekt_utf[$i]['location_code'];
 			}
 
-			$this->db->transaction_commit();
-			$this->db_boei->transaction_commit();
+		//	$this->db->transaction_commit();
+		//	$this->db_boei->transaction_commit();
 
 			$msg = count($leieobjekt) . ' Leieobjekt er lagt til: ' . @implode(",", $leieobjekt_msg);
 			$this->receipt['message'][]=array('msg'=> $msg);
@@ -531,7 +600,17 @@
 
 			while ($this->db_boei->next_record())
 			{
-				$leietaker[]= array (
+				$leietaker_utf[]= array (
+				 'id' 				=> $this->db_boei->f('leietaker_id'),
+				 'first_name'		=> $this->bocommon->ascii2utf($this->db_boei->f('fornavn')),
+				 'last_name' 		=> $this->bocommon->ascii2utf($this->db_boei->f('etternavn')),
+				 'category'			=> $this->db_boei->f('kjonn_juridisk') + 1,
+				 'status_eco'		=> $this->db_boei->f('namssakstatusokonomi_id'),
+				 'status_drift' 	=> $this->db_boei->f('namssakstatusdrift_id'),
+				 'entry_date'		=> time(),
+				 'owner_id'			=> 6
+				 );
+				$leietaker_latin[]= array (
 				 'id' 				=> $this->db_boei->f('leietaker_id'),
 				 'first_name'		=> $this->db_boei->f('fornavn'),
 				 'last_name' 		=> $this->db_boei->f('etternavn'),
@@ -543,24 +622,29 @@
 				 );
 			}
 
-			$this->db->transaction_begin();
-			$this->db_boei->transaction_begin();
+		//	$this->db->transaction_begin();
+		//	$this->db_boei->transaction_begin();
 
-			for ($i=0; $i<count($leietaker); $i++)
+			for ($i=0; $i<count($leietaker_latin); $i++)
 			{
-				$sql2 = "INSERT INTO fm_tenant (id, first_name, last_name, category, status_eco, status_drift,entry_date,owner_id)"
-					. "VALUES (" . $this->bocommon->validate_db_insert($leietaker[$i]) . ")";
+				$this->db->query("DELETE FROM fm_tenant WHERE id=" . (int)$leietaker_latin[$i]['id'],__LINE__,__FILE__);
+				$this->db_boei->query("DELETE FROM fm_tenant WHERE id=" . (int)$leietaker_latin[$i]['id'],__LINE__,__FILE__);
 
-				$this->db->query($sql2,__LINE__,__FILE__);
-				$this->db_boei->query($sql2,__LINE__,__FILE__);
+				$sql2_utf = "INSERT INTO fm_tenant (id, first_name, last_name, category, status_eco, status_drift,entry_date,owner_id)"
+					. "VALUES (" . $this->bocommon->validate_db_insert($leietaker_utf[$i]) . ")";
+				$sql2_latin = "INSERT INTO fm_tenant (id, first_name, last_name, category, status_eco, status_drift,entry_date,owner_id)"
+					. "VALUES (" . $this->bocommon->validate_db_insert($leietaker_latin[$i]) . ")";
 
-				$leietaker_msg[]= '[' .$leietaker[$i]['last_name'] . ', ' . $leietaker[$i]['first_name'] . ']';
+				$this->db->query($sql2_utf,__LINE__,__FILE__);
+				$this->db_boei->query($sql2_latin,__LINE__,__FILE__);
+
+				$leietaker_msg[]= '[' .$leietaker_utf[$i]['last_name'] . ', ' . $leietaker_utf[$i]['first_name'] . ']';
 			}
 
-			$this->db->transaction_commit();
-			$this->db_boei->transaction_commit();
+		//	$this->db->transaction_commit();
+		//	$this->db_boei->transaction_commit();
 
-			$msg = count($leietaker) . ' Leietaker er lagt til: ' . @implode(",", $leietaker_msg);
+			$msg = count($leietaker_latin) . ' Leietaker er lagt til: ' . @implode(",", $leietaker_msg);
 			$this->receipt['message'][]=array('msg'=> $msg);
 			unset ($leietaker);
 			unset ($leietaker_msg);
@@ -569,20 +653,28 @@
 		}
 
 		function oppdater_leieobjekt()
-		{
-
+		{			
 			$sql = " SELECT TOP 100 PERCENT objekt_id,leie_id,leietaker_id, boareal, formaal_id, gateadresse_id, gatenr, etasje,driftsstatus_id"
 				. " FROM  v_Leieobjekt"; // WHERE v_Leieobjekt.formaal_id NOT IN (99)";
 
 			$this->db_boei->query($sql,__LINE__,__FILE__);
 
-			$this->db->transaction_begin();
-			$this->db_boei->transaction_begin();
+		//	$this->db->transaction_begin();
+		//	$this->db_boei2->transaction_begin();
 
 			$i=0;
 			while ($this->db_boei->next_record())
 			{
-				$sql2 = " UPDATE  fm_location4 SET "
+				$sql2_utf = " UPDATE  fm_location4 SET "
+				. " tenant_id = '" . $this->db_boei->f('leietaker_id') . "',"
+				. " category = '" . $this->db_boei->f('formaal_id') . "',"
+				. " etasje = '" . $this->bocommon->ascii2utf($this->db_boei->f('etasje')) . "',"
+				. " street_id = '" . $this->db_boei->f('gateadresse_id') . "',"
+				. " street_number = '" . $this->bocommon->ascii2utf($this->db_boei->f('gatenr')) . "',"
+				. " driftsstatus_id = '" . $this->db_boei->f('driftsstatus_id') . "',"
+				. " boareal = '" . $this->db_boei->f('boareal') . "'"
+				. " WHERE  loc1 = '" . $this->db_boei->f('objekt_id') . "'  AND  loc4= '" . $this->db_boei->f('leie_id') . "'";
+				$sql2_latin = " UPDATE  fm_location4 SET "
 				. " tenant_id = '" . $this->db_boei->f('leietaker_id') . "',"
 				. " category = '" . $this->db_boei->f('formaal_id') . "',"
 				. " etasje = '" . $this->db_boei->f('etasje') . "',"
@@ -592,13 +684,13 @@
 				. " boareal = '" . $this->db_boei->f('boareal') . "'"
 				. " WHERE  loc1 = '" . $this->db_boei->f('objekt_id') . "'  AND  loc4= '" . $this->db_boei->f('leie_id') . "'";
 
-				$this->db->query($sql2,__LINE__,__FILE__);
-				$this->db_boei2->query($sql2,__LINE__,__FILE__);
+				$this->db->query($sql2_utf,__LINE__,__FILE__);
+				$this->db_boei2->query($sql2_latin,__LINE__,__FILE__);
 				$i++;
 			}
 
-			$this->db->transaction_begin();
-			$this->db_boei->transaction_begin();
+		//	$this->db->transaction_commit();
+		//	$this->db_boei2->transaction_commit();
 
 			$msg = $i . ' Leieobjekt er oppdatert';
 			$this->receipt['message'][]=array('msg'=> $msg);
@@ -616,13 +708,21 @@
 
 			$this->db_boei->query($sql,__LINE__,__FILE__);
 
-			$this->db->transaction_begin();
-			$this->db_boei->transaction_begin();
+		//	$this->db->transaction_begin();
+		//	$this->db_boei2->transaction_begin();
 
 			$i=0;
 			while ($this->db_boei->next_record())
 			{
-				$sql2 = " UPDATE fm_location1 SET "
+				$sql2_utf = " UPDATE fm_location1 SET "
+				. " loc1_name = '" . $this->bocommon->ascii2utf($this->db_boei->f('navn')) . "',"
+				. " sum_boa = '" . $this->db_boei->f('sum_boa') . "',"
+				. " ant_leieobjekt = '" . $this->db_boei->f('ant_leieobjekt') . "',"
+				. " part_of_town_id = '" . $this->db_boei->f('bydel_id') . "',"
+				. " owner_id = '" . $this->db_boei->f('eier_id') . "',"
+				. " kostra_id = '" . $this->db_boei->f('tjenestested') . "'"
+				. " WHERE  loc1 = '" . $this->db_boei->f('objekt_id') . "'";
+				$sql2_latin = " UPDATE fm_location1 SET "
 				. " loc1_name = '" . $this->db_boei->f('navn') . "',"
 				. " sum_boa = '" . $this->db_boei->f('sum_boa') . "',"
 				. " ant_leieobjekt = '" . $this->db_boei->f('ant_leieobjekt') . "',"
@@ -631,12 +731,12 @@
 				. " kostra_id = '" . $this->db_boei->f('tjenestested') . "'"
 				. " WHERE  loc1 = '" . $this->db_boei->f('objekt_id') . "'";
 
-				$this->db->query($sql2,__LINE__,__FILE__);
-				$this->db_boei2->query($sql2,__LINE__,__FILE__);
+				$this->db->query($sql2_utf,__LINE__,__FILE__);
+				$this->db_boei2->query($sql2_latin,__LINE__,__FILE__);
 				$i++;
 			}
-			$this->db->transaction_begin();
-			$this->db_boei->transaction_begin();
+		//	$this->db->transaction_commit();
+		//	$this->db_boei2->transaction_commit();
 
 			$msg = $i . ' Objekt er oppdatert';
 			$this->receipt['message'][]=array('msg'=> $msg);
@@ -655,24 +755,29 @@
 
 			$this->db_boei->query($sql,__LINE__,__FILE__);
 
-			$this->db->transaction_begin();
-			$this->db_boei->transaction_begin();
+		//	$this->db->transaction_begin();
+		//	$this->db_boei2->transaction_begin();
 
 			$i=0;
 			while ($this->db_boei->next_record())
 			{
-				$sql2 = " UPDATE fm_location2 SET "
+				$sql2_utf = " UPDATE fm_location2 SET "
+				. " loc2_name = '" . $this->bocommon->ascii2utf($this->db_boei->f('byggnavn')) . "',"
+				. " sum_boa = '" . $this->db_boei->f('sum_boa') . "',"
+				. " ant_leieobjekt = '" . $this->db_boei->f('ant_leieobjekt') . "'"
+				. " WHERE  loc1 = '" . $this->db_boei->f('objekt_id') . "'  AND  loc2= '" . $this->db_boei->f('bygg_id') . "'";
+				$sql2_latin = " UPDATE fm_location2 SET "
 				. " loc2_name = '" . $this->db_boei->f('byggnavn') . "',"
 				. " sum_boa = '" . $this->db_boei->f('sum_boa') . "',"
 				. " ant_leieobjekt = '" . $this->db_boei->f('ant_leieobjekt') . "'"
 				. " WHERE  loc1 = '" . $this->db_boei->f('objekt_id') . "'  AND  loc2= '" . $this->db_boei->f('bygg_id') . "'";
 
-				$this->db->query($sql2,__LINE__,__FILE__);
-				$this->db_boei2->query($sql2,__LINE__,__FILE__);
+				$this->db->query($sql2_utf,__LINE__,__FILE__);
+				$this->db_boei2->query($sql2_utf,__LINE__,__FILE__);
 				$i++;
 			}
-			$this->db->transaction_begin();
-			$this->db_boei->transaction_begin();
+		//	$this->db->transaction_commit();
+		//	$this->db_boei2->transaction_commit();
 
 			$msg = $i . ' Bygg er oppdatert';
 			$this->receipt['message'][]=array('msg'=> $msg);
@@ -694,23 +799,28 @@
 
 			$i=0;
 
-			$this->db->transaction_begin();
-			$this->db_boei->transaction_begin();
+		//	$this->db->transaction_begin();
+		//	$this->db_boei2->transaction_begin();
 
 			while ($this->db_boei->next_record())
 			{
-				$sql2 = " UPDATE fm_location3 SET "
+				$sql2_utf = " UPDATE fm_location3 SET "
+				. " loc3_name = '" . $this->bocommon->ascii2utf($this->db_boei->f('beskrivelse')) . "',"
+				. " sum_boa = '" . $this->db_boei->f('sum_boa') . "',"
+				. " ant_leieobjekt = '" . $this->db_boei->f('ant_leieobjekt') . "'"
+				. " WHERE  loc1 = '" . $this->db_boei->f('objekt_id') . "'  AND  loc2= '" . $this->db_boei->f('bygg_id') . "'  AND  loc3= '" . $this->db_boei->f('seksjons_id') . "'";
+				$sql2_latin = " UPDATE fm_location3 SET "
 				. " loc3_name = '" . $this->db_boei->f('beskrivelse') . "',"
 				. " sum_boa = '" . $this->db_boei->f('sum_boa') . "',"
 				. " ant_leieobjekt = '" . $this->db_boei->f('ant_leieobjekt') . "'"
 				. " WHERE  loc1 = '" . $this->db_boei->f('objekt_id') . "'  AND  loc2= '" . $this->db_boei->f('bygg_id') . "'  AND  loc3= '" . $this->db_boei->f('seksjons_id') . "'";
 
-				$this->db->query($sql2,__LINE__,__FILE__);
-				$this->db_boei2->query($sql2,__LINE__,__FILE__);
+				$this->db->query($sql2_utf,__LINE__,__FILE__);
+				$this->db_boei2->query($sql2_latin,__LINE__,__FILE__);
 				$i++;
 			}
-			$this->db->transaction_begin();
-			$this->db_boei->transaction_begin();
+		//	$this->db->transaction_commit();
+		//	$this->db_boei2->transaction_commit();
 
 			$msg = $i . ' Seksjoner er oppdatert';
 			$this->receipt['message'][]=array('msg'=> $msg);
@@ -728,8 +838,8 @@
 
 			$this->db_boei->query($sql,__LINE__,__FILE__);
 
-			$this->db->transaction_begin();
-			$this->db_boei->transaction_begin();
+	//		$this->db->transaction_begin();
+	//		$this->db_boei->transaction_begin();
 
 			while ($this->db_boei->next_record())
 			{
@@ -762,8 +872,8 @@
 				$this->db_boei->query($sql,__LINE__,__FILE__);
 			}
 
-			$this->db->transaction_commit();
-			$this->db_boei->transaction_commit();
+		//	$this->db->transaction_commit();
+		//	$this->db_boei->transaction_commit();
 
 			$msg = $i . ' oppsagtdato er oppdatert';
 			$this->receipt['message'][]=array('msg'=> $msg);
