@@ -8,7 +8,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage setup
- 	* @version $Id: tables_update.inc.php,v 1.65 2007/01/02 14:43:03 sigurdne Exp $
+ 	* @version $Id: tables_update.inc.php,v 1.66 2007/03/16 14:14:56 sigurdne Exp $
 	*/
 
 	/**
@@ -1756,4 +1756,24 @@
 	}
 
 
+	/**
+	* Update property version from 0.9.17.536 to 0.9.17.537
+	*/
 
+	$test[] = '0.9.17.536';
+	function property_upgrade0_9_17_536()
+	{
+		$GLOBALS['phpgw_setup']->oProc->m_odb->transaction_begin();
+
+		$GLOBALS['phpgw_setup']->oProc->AlterColumn('fm_project','end_date',array(
+			'type' => 'int',
+			'precision' => 4,
+			'nullable' => 'True'
+		));
+
+		if($GLOBALS['phpgw_setup']->oProc->m_odb->transaction_commit())
+		{
+			$GLOBALS['setup_info']['property']['currentver'] = '0.9.17.537';
+			return $GLOBALS['setup_info']['property']['currentver'];
+		}
+	}
\ No newline at end of file
