@@ -1,5 +1,5 @@
 #!/bin/bash
-# $Id: install.apache.sh,v 1.5 2007/01/16 13:35:08 sigurdne Exp $ 
+# $Id: install.apache.sh,v 1.7 2007/05/07 19:23:22 sigurdne Exp $ 
 
 #/**
 #  * installscript for APACHE with PHP, IMAP, POSTGRESQL, MYSQL, LIBXML, XSLT, FREEDTS(MSSQL) and EACCELERATOR
@@ -25,14 +25,14 @@
 FREETDSTAR="freetds-stable.tgz"
 FREETDS="freetds-0.64"
 
-LIBXMLTAR="libxml2-2.6.27.tar.gz"
-LIBXML="libxml2-2.6.27"
+LIBXMLTAR="libxml2-2.6.28.tar.gz"
+LIBXML="libxml2-2.6.28"
 
-LIBXSLTAR="libxslt-1.1.19.tar.gz"
-LIBXSL="libxslt-1.1.19"
+LIBXSLTAR="libxslt-1.1.20.tar.gz"
+LIBXSL="libxslt-1.1.20"
 
-IMAPTAR="imap-2006d.tar.Z"
-IMAP="imap-2006d"
+IMAPTAR="imap-2006h.tar.Z"
+IMAP="imap-2006h"
 
 PHP_PREFIX="/usr/local"
 
@@ -49,16 +49,16 @@ APACHE="httpd-2.2.4"
 #  * 
 #  * @var               string PHP, PHPTAR
 #  */
-PHPTAR="php-5.2.0.tar.bz2"
-PHP="php-5.2.0"
+PHPTAR="php-5.2.2.tar.bz2"
+PHP="php-5.2.2"
 
 #/**
-#  * Name of the MMCACHE tarball e.g turck-mmcache-2.4.6.tar.gz
+#  * Name of the EACCELERATOR tarball e.g eaccelerator-0.9.5.tar.bz2
 #  * 
-#  * @var               string MMCACHE, MMCACHETAR
+#  * @var               string EACCELERATOR, EACCELERATORTAR
 #  */
-EACCELERATORTAR="eaccelerator-0.9.5.tar.bz2"
-EACCELERATOR="eaccelerator-0.9.5"
+EACCELERATORTAR="eaccelerator-0.9.5.1.tar.bz2"
+EACCELERATOR="eaccelerator-0.9.5.1"
 
 # perform the install
 
