@@ -5,7 +5,7 @@
 	* @copyright Portions Copyright (C) 2000-2005 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package setup
-	* @version $Id: manageheader.php,v 1.1 2007/02/14 14:58:20 sigurdne Exp $
+	* @version $Id: manageheader.php,v 1.2 2007/03/18 22:39:59 sigurdne Exp $
 	*/
 
 	$phpgw_info = array();
@@ -529,6 +529,15 @@
 				$setup_tpl->set_var('phpgw_handle_error_no',' selected');
 			}
 
+			if(@$GLOBALS['phpgw_info']['server']['db_abstraction'])
+			{
+				$setup_tpl->set_var('db_abstraction_phplib',' selected');
+			}
+			else
+			{
+				$setup_tpl->set_var('db_abstraction_adodb',' selected');
+			}
+
 			$errors = '';
 			if( !isset($found_dbtype) || !$found_dbtype )
 			{
@@ -586,6 +595,7 @@
 			$setup_tpl->set_var('lang_domain_from_host', lang('Automatically detect domain from hostname'));
 			$setup_tpl->set_var('lang_note_domain_from_host', lang('Note: This option will only work if show domain select box is off.'));
 			$setup_tpl->set_var('lang_phpgw_handle_error',lang('Enable custom error handle for heavy debugging'));
+			$setup_tpl->set_var('lang_db_abstraction',lang('Choose db abstraction'));
 			$setup_tpl->set_var('lang_finaldescr',lang('After retrieving the file, put it into place as the header.inc.php.  Then, click "continue".'));
 			$setup_tpl->set_var('lang_continue',lang('Continue'));
 
