@@ -8,7 +8,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package sms
 	* @subpackage sms
- 	* @version $Id: class.sms.inc.php,v 1.23 2007/02/26 22:21:07 sigurdne Exp $
+ 	* @version $Id: class.sms.inc.php,v 1.24 2007/03/10 15:21:59 sigurdne Exp $
 	*/
 
 	/**
@@ -204,8 +204,10 @@
 					(uid,p_gateway,p_src,p_dst,p_footer,p_msg,p_datetime,p_sms_type,unicode) 
 					VALUES ('$uid','$gateway_module','$mobile_sender','$c_sms_to','$sms_sender','$message','$datetime_now','$sms_type','$unicode')";
 		
+				$GLOBALS['phpgw']->db->transaction_begin();
 				$GLOBALS['phpgw']->db->query($db_query,__LINE__,__FILE__);
-				$smslog_id = $GLOBALS['phpgw']->db->get_last_insert_id(phpgw_sms_tblSMSOutgoing,'smslog_id');
+				$smslog_id = $GLOBALS['phpgw']->db->get_last_insert_id('phpgw_sms_tblSMSOutgoing','smslog_id');
+				$GLOBALS['phpgw']->db->transaction_commit();
 		
 				$gp_code = "PV";
 				$to[$i] = $c_sms_to;
